/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 470 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 955 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1212 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1286 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1307 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1509 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1719 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 263
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 75
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  SrcList* yy39;
  IdList* yy40;
  int yy116;
  enum trim_side_mask yy157;
  struct alter_args yy158;
  struct ExprList * yy179;
  With* yy231;
  TriggerStep* yy255;
  struct LimitVal yy320;
  ExprList* yy338;
  Expr* yy366;
  ExprSpan yy382;
  struct SrcList * yy396;
  struct TrigEvent yy434;
  struct Expr * yy443;
  bool yy461;
  Select* yy479;
  struct Token yy503;
  struct type_def yy518;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             428
#define YYNRULE              307
#define YY_MAX_SHIFT         427
#define YY_MIN_SHIFTREDUCE   640
#define YY_MAX_SHIFTREDUCE   946
#define YY_MIN_REDUCE        947
#define YY_MAX_REDUCE        1253
#define YY_ERROR_ACTION      1254
#define YY_ACCEPT_ACTION     1255
#define YY_NO_ACTION         1256
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1550)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    66,   67,  285,  305,  822,  822,  832,  835,   64,   64,
 /*    10 */    65,   65,   65,   65,  298,   63,   63,   63,   63,   62,
 /*    20 */    62,   61,   61,   61,   60,  306,   65,   65,   65,   65,
 /*    30 */    58,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*    40 */    60,  306,  937,  306,  937, 1255,  427,    2,   66,   67,
 /*    50 */   285,  305,  822,  822,  832,  835,   64,   64,   65,   65,
 /*    60 */    65,   65,  245,   63,   63,   63,   63,   62,   62,   61,
 /*    70 */    61,   61,   60,  306,   59,   57,  183,   66,   67,  285,
 /*    80 */   305,  822,  822,  832,  835,   64,   64,   65,   65,   65,
 /*    90 */    65,  214,   63,   63,   63,   63,   62,   62,   61,   61,
 /*   100 */    61,   60,  306,  853,  658,   53,  905,  906,  907,  908,
 /*   110 */   909,  910,  268,  913,  914,  915,  915,  916,  244,  738,
 /*   120 */    43,  861,   50,   51,  883,  883,  421,  113,  113,   52,
 /*   130 */    62,   62,   61,   61,   61,   60,  306,  335,  869,   68,
 /*   140 */   411,    4,   99,   99,  421,  792,  753,  307,  307,  121,
 /*   150 */   184,  184,  341,  341,  758,  759,  308,  322,  308,  279,
 /*   160 */    25,   25,  379,  237,  283,  392,  400,   72,  113,  308,
 /*   170 */   892,  869,  339,  350,  287,  128,  787,  328,  892,  395,
 /*   180 */   393,  191,   65,   65,   65,   65,  658,   63,   63,   63,
 /*   190 */    63,   62,   62,   61,   61,   61,   60,  306,   49,  413,
 /*   200 */    47,   59,   57,  183,  789,   63,   63,   63,   63,   62,
 /*   210 */    62,   61,   61,   61,   60,  306,  662,  413,  791,  791,
 /*   220 */   793,  794,  795,  796,  797,  419,  415,  807,  808,  809,
 /*   230 */   941,   19,   66,   67,  285,  305,  822,  822,  832,  835,
 /*   240 */    64,   64,   65,   65,   65,   65,  358,   63,   63,   63,
 /*   250 */    63,   62,   62,   61,   61,   61,   60,  306,   66,   67,
 /*   260 */   285,  305,  822,  822,  832,  835,   64,   64,   65,   65,
 /*   270 */    65,   65,  665,   63,   63,   63,   63,   62,   62,   61,
 /*   280 */    61,   61,   60,  306,   67,  285,  305,  822,  822,  832,
 /*   290 */   835,   64,   64,   65,   65,   65,   65,  893,   63,   63,
 /*   300 */    63,   63,   62,   62,   61,   61,   61,   60,  306,  343,
 /*   310 */   675,   61,   61,   61,   60,  306,   66,   67,  285,  305,
 /*   320 */   822,  822,  832,  835,   64,   64,   65,   65,   65,   65,
 /*   330 */   248,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   340 */    60,  306,  311,  895,  313,    6,  426,  426,  936,  937,
 /*   350 */   276,  937,  641,  310,  125,  670,  316,  823,  823,  833,
 /*   360 */   836,   66,   67,  285,  305,  822,  822,  832,  835,   64,
 /*   370 */    64,   65,   65,   65,   65,  194,   63,   63,   63,   63,
 /*   380 */    62,   62,   61,   61,   61,   60,  306,  657,  712,  928,
 /*   390 */   284,   71,  752,  664,  129,  928,  250,  249,  214,  672,
 /*   400 */   663,  369,  669,  368,  209,  160,   66,   67,  285,  305,
 /*   410 */   822,  822,  832,  835,   64,   64,   65,   65,   65,   65,
 /*   420 */   421,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   430 */    60,  306,  184,  184,  938,  938,   25,   25,  128,  166,
 /*   440 */   165,   60,  306,  266,  379,  813,  312,   59,   57,  183,
 /*   450 */   293,   66,   67,  285,  305,  822,  822,  832,  835,   64,
 /*   460 */    64,   65,   65,   65,   65,  318,   63,   63,   63,   63,
 /*   470 */    62,   62,   61,   61,   61,   60,  306,  656,  128,  928,
 /*   480 */   284,  149,  681,  250,  249,  928,  683,  684,  685,  672,
 /*   490 */   786,  939,  741,  413, 1207, 1207,   66,   67,  285,  305,
 /*   500 */   822,  822,  832,  835,   64,   64,   65,   65,   65,   65,
 /*   510 */   327,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   520 */    60,  306,   66,   67,  285,  305,  822,  822,  832,  835,
 /*   530 */    64,   64,   65,   65,   65,   65,  409,   63,   63,   63,
 /*   540 */    63,   62,   62,   61,   61,   61,   60,  306,   66,   67,
 /*   550 */   285,  305,  822,  822,  832,  835,   64,   64,   65,   65,
 /*   560 */    65,   65,  418,   63,   63,   63,   63,   62,   62,   61,
 /*   570 */    61,   61,   60,  306,   66,   67,  285,  305,  822,  822,
 /*   580 */   832,  835,   64,   64,   65,   65,   65,   65,  725,   63,
 /*   590 */    63,   63,   63,   62,   62,   61,   61,   61,   60,  306,
 /*   600 */    53,  320,  938,  938,  164,  163,   59,   57,  183,  671,
 /*   610 */   682,  250,  249,  781,  364,  362,  368,   50,   51,  319,
 /*   620 */   858,  756,  757,   70,   52,  732,   45,  792,  361,  229,
 /*   630 */   330,  381,  213,  792,  113,  411,    4, 1154,  128,  421,
 /*   640 */   792,  886,  307,  307,  418,  221,  376,  146,  803,  169,
 /*   650 */   181,  288,   48,  659,  659,   25,   25,  887,  787,  939,
 /*   660 */   740,  400,  699,  241,  787,  122,  386,  888,  399,  295,
 /*   670 */   699,  787,  176,  285,  305,  822,  822,  832,  835,   64,
 /*   680 */    64,   65,   65,   65,   65,  171,   63,   63,   63,   63,
 /*   690 */    62,   62,   61,   61,   61,   60,  306,  659,  659,  789,
 /*   700 */   791,  791,  793,  794,  795,  796,  791,  791,  793,  794,
 /*   710 */   795,  796,  413,  791,  791,  793,  794,  795,  796,  797,
 /*   720 */   419,  415,  704,  704,  755,  941,   19,   66,   67,  285,
 /*   730 */   305,  822,  822,  832,  835,   64,   64,   65,   65,   65,
 /*   740 */    65,   40,   63,   63,   63,   63,   62,   62,   61,   61,
 /*   750 */    61,   60,  306,   66,   56,  285,  305,  822,  822,  832,
 /*   760 */   835,   64,   64,   65,   65,   65,   65,   53,   63,   63,
 /*   770 */    63,   63,   62,   62,   61,   61,   61,   60,  306,  371,
 /*   780 */   128,  659,  659,  147,   50,   51,   59,   57,  183,  659,
 /*   790 */   659,   52,  301,  425,  152,  645,  424,  224,  277,   53,
 /*   800 */   785,  651,  411,    4,  781,  128,  128,  792,  222,  307,
 /*   810 */   307,  689,  866,  739,  865,  297,   50,   51,  726,  366,
 /*   820 */   240,  340,  333,   52,  690,  343,  727,  220,  400,  981,
 /*   830 */   937,  421,  937,  981,  411,    4,  421,   29,  787,  792,
 /*   840 */   738,  307,  307,  375,  299,  717,  717,   82,   82,  659,
 /*   850 */   659,  722,   27,   27,  241,  282,  721,  738,  421,  398,
 /*   860 */   400,  222,  162,  255,  334,  296,  789,  738,  675,  338,
 /*   870 */   787,  172,  739,  421,   97,   97,  248,  326,  770,  214,
 /*   880 */   791,  791,  793,  794,  795,  796,  797,  419,  415,   99,
 /*   890 */    99,  200,  941,   19,  421,  228,  221,  376,  789,  193,
 /*   900 */   414,   54,   18,  179,  413,  195,  323,  739,  754,  413,
 /*   910 */    79,   79,  791,  791,  793,  794,  795,  796,  797,  419,
 /*   920 */   415,   53,  702,  702,  941,   19,  395,  377,  128,  174,
 /*   930 */   394,  413,  421,  373,  421,  738,  113,  421,   50,   51,
 /*   940 */   354,  351,  421,  863,  345,   52,  413,  374,   99,   99,
 /*   950 */    99,   99,  781,   99,   99,  738,  411,    4,   99,   99,
 /*   960 */   421,  792,  349,  307,  307,  172,  739,  413,  240,  340,
 /*   970 */    59,   57,  183,  196,  121,  778,   99,   99,  113,  785,
 /*   980 */   790,  266,  400,  926,  280,  395,  382,  395,  391,  283,
 /*   990 */   395,  412,  787,  889,  926,  395,  372,   73,  785,  785,
 /*  1000 */   421,  349,  241,  659,  659,  413,  421,  413,  380,  420,
 /*  1010 */   413,  738,    1,  302,  421,  413,   99,   99,  659,  659,
 /*  1020 */   789,  722,   97,   97,   24,   24,  721,  659,  659,  349,
 /*  1030 */    25,   25,  886,  413,  791,  791,  793,  794,  795,  796,
 /*  1040 */   797,  419,  415,  290,  389,  738,  941,   19,  887,  859,
 /*  1050 */   199,  421,  738,  387,  421,  758,  759,  170,  888,  705,
 /*  1060 */   421,  785,  291,  292,  738,  858,  706,   75,   75,  421,
 /*  1070 */    84,   84,  257,  413,  405,  421,   85,   85,  265,  413,
 /*  1080 */   826,  413,  421,  708,  421,   86,   86,  413,  421,  239,
 /*  1090 */   707,   87,   87,  421,  234,  421,  294,  421,   88,   88,
 /*  1100 */    28,   28,  236,  421,   76,   76,  421,  264,  858,   78,
 /*  1110 */    78,   89,   89,   90,   90,  421,  695,  202,  421,   91,
 /*  1120 */    91,  421,   26,   26,  413,  303,  881,  413,  421,  113,
 /*  1130 */   421,   92,   92,  413,   93,   93,  421,   94,   94,  304,
 /*  1140 */   714,  254,  413,  421,   80,   80,   95,   95,  413,  696,
 /*  1150 */   233,  379,   96,   96,  253,  413,  421,  413,  421,   81,
 /*  1160 */    81,  413,  711,  673,  673,  113,  413,  421,  413,  421,
 /*  1170 */   413,  185,  118,  118,  119,  119,  413,  154,  402,  413,
 /*  1180 */   421,  113,  421,  120,  120,  103,  103,  406,  413,  421,
 /*  1190 */   113,  413,  232,  383,  413,  231,   98,   98,   83,   83,
 /*  1200 */   227,  413,  421,  413,  421,  106,  106,  421,  719,  413,
 /*  1210 */   410,  421,   44,  113,  182,  181,  413,  259,  100,  100,
 /*  1220 */   107,  107,  261,  105,  105,    9,  347,  117,  117,  413,
 /*  1230 */   899,  413,  966,  421,  894,  421,  384,  314,   42,  897,
 /*  1240 */   413,  216,  413,  421,  167,  168,  688,  687,  421,  112,
 /*  1250 */   112,  111,  111,  413,  421,  413,  891,  748,  898,  110,
 /*  1260 */   110,  212,  413,  324,  108,  108,  421,  289,  325,  348,
 /*  1270 */   109,  109,  421,  798,  798,  413,  421,  413,  421,  773,
 /*  1280 */   413,  421,  102,  102,  413,  329,  783,  342,  104,  104,
 /*  1290 */   212,  212,  101,  101,   74,   74,  344,   77,   77,  852,
 /*  1300 */   212,  230,  331,   42,  175,  359,  413,  698,  413,  216,
 /*  1310 */   697,   42,  880,  238,   36,  856,  413,  878,  923,  216,
 /*  1320 */   346,  413,   23,  877,  352,  668,  353,  413,  243,  650,
 /*  1330 */   263,  247,  252,  746,  784,    8,  728,  857,  401,  413,
 /*  1340 */   267,  273,  161,  660,  648,  413,  647,  649,  286,  413,
 /*  1350 */   153,  413,  144,  133,  413,  123,  135,   40,  769,  332,
 /*  1360 */   114,   31,  226,  864,  137,  337,  357,  235,  198,  155,
 /*  1370 */   205,  206,  355,  207,  300,  115,  197,  365,  246,  139,
 /*  1380 */   678,  367,  140,  148,  780,  116,  693,  679,  692,  251,
 /*  1390 */   370,  667,  666,  385,   39,  882,    7,  840,   46,  215,
 /*  1400 */   417,  404,  408,  912,   69,  390,   41,  388,  423,  924,
 /*  1410 */   274,   10,  920,  281,  275,  223,  736,  643,  225,  922,
 /*  1420 */   309,  718,   20,   11,   21,  896,  270,  256,   30,  186,
 /*  1430 */   271,  737,  258,  269,  735,  272,  260,  130,  734,  262,
 /*  1440 */   315,  317,  187,  188,  862,  189,  190,  131,  321,  192,
 /*  1450 */   132,  779,  134,  126,  709,  138,  136,  867,  212,  943,
 /*  1460 */   141,  142,  876,  336,  145,   32,  143,   33,   34,   35,
 /*  1470 */   879,  127,  201,  875,   22,   12,  203,  204,  242,  156,
 /*  1480 */   653,  356,  253,  208,  150,  360,   13,   14,  363,  167,
 /*  1490 */    37,  691,  210,  168,  124,  716,  812,   38,  378,  177,
 /*  1500 */   810,  838,   15,  742,  720,    5,  211,  178,  180,  151,
 /*  1510 */    16,   17,  416,  827,  851,  747,   44,   42,  396,  839,
 /*  1520 */   837,  804,  885,  884,  173,  397,  903,  842,  157,  403,
 /*  1530 */   904,  217,  158,  407,  841,  159,  422,  811,  218,  644,
 /*  1540 */   800,    3,  278,  911,  799,   55,  219,  640,  654, 1224,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,   84,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,   30,   49,  160,  161,  162,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,   39,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,  240,  241,  242,    5,    6,    7,
 /*    80 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    90 */    18,   96,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   100 */    28,   29,   30,   80,  179,    7,  147,  148,  149,  150,
 /*   110 */   151,  152,  153,  154,  155,  156,  157,  158,   95,  166,
 /*   120 */    48,   44,   24,   25,  205,  205,  166,  208,  208,   31,
 /*   130 */    24,   25,   26,   27,   28,   29,   30,   85,   86,   67,
 /*   140 */    42,   43,  182,  183,  166,   47,  185,   49,   50,  166,
 /*   150 */   206,  207,  233,  233,  111,  112,  173,  204,  175,  176,
 /*   160 */   182,  183,  218,  140,  181,  205,   68,  248,  208,  186,
 /*   170 */   190,  119,  253,  253,  196,   45,   78,  233,  198,  219,
 /*   180 */   220,  104,   15,   16,   17,   18,  261,   20,   21,   22,
 /*   190 */    23,   24,   25,   26,   27,   28,   29,   30,  134,  239,
 /*   200 */   136,  240,  241,  242,  106,   20,   21,   22,   23,   24,
 /*   210 */    25,   26,   27,   28,   29,   30,  182,  239,  120,  121,
 /*   220 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   230 */   132,  133,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   240 */    13,   14,   15,   16,   17,   18,    7,   20,   21,   22,
 /*   250 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   260 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   270 */    17,   18,  182,   20,   21,   22,   23,   24,   25,   26,
 /*   280 */    27,   28,   29,   30,    6,    7,    8,    9,   10,   11,
 /*   290 */    12,   13,   14,   15,   16,   17,   18,   44,   20,   21,
 /*   300 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  166,
 /*   310 */    83,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*   320 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   330 */    91,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   340 */    29,   30,   79,   80,   81,   43,  163,  164,   48,   47,
 /*   350 */   167,   49,    1,    2,  171,   44,   93,    9,   10,   11,
 /*   360 */    12,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   370 */    14,   15,   16,   17,   18,  232,   20,   21,   22,   23,
 /*   380 */    24,   25,   26,   27,   28,   29,   30,  178,  205,  180,
 /*   390 */   181,  208,  185,  182,  189,  186,  191,  192,   96,  190,
 /*   400 */    44,   79,   80,   81,   82,  105,    5,    6,    7,    8,
 /*   410 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   420 */   166,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   430 */    29,   30,  206,  207,   49,   50,  182,  183,   45,  256,
 /*   440 */   257,   29,   30,  166,  218,   44,  258,  240,  241,  242,
 /*   450 */   196,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   460 */    14,   15,   16,   17,   18,  231,   20,   21,   22,   23,
 /*   470 */    24,   25,   26,   27,   28,   29,   30,  178,   45,  180,
 /*   480 */   181,  189,  193,  191,  192,  186,   87,   88,   89,  190,
 /*   490 */    44,  106,  107,  239,  101,  102,    5,    6,    7,    8,
 /*   500 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   510 */    77,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   520 */    29,   30,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   530 */    13,   14,   15,   16,   17,   18,  259,   20,   21,   22,
 /*   540 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   550 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   560 */    17,   18,  179,   20,   21,   22,   23,   24,   25,   26,
 /*   570 */    27,   28,   29,   30,    5,    6,    7,    8,    9,   10,
 /*   580 */    11,   12,   13,   14,   15,   16,   17,   18,  222,   20,
 /*   590 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   600 */     7,   53,   49,   50,   24,   25,  240,  241,  242,  189,
 /*   610 */   193,  191,  192,   69,   79,   80,   81,   24,   25,   71,
 /*   620 */   166,   73,   74,   43,   31,  225,  135,   47,   93,   85,
 /*   630 */    86,  205,  222,   47,  208,   42,   43,   44,   45,  166,
 /*   640 */    47,   35,   49,   50,  261,  101,  102,   43,  105,  223,
 /*   650 */   224,  197,  135,   49,   50,  182,  183,   51,   78,  106,
 /*   660 */   107,   68,  190,  119,   78,   96,  229,   61,   62,  196,
 /*   670 */   198,   78,   48,    7,    8,    9,   10,   11,   12,   13,
 /*   680 */    14,   15,   16,   17,   18,  229,   20,   21,   22,   23,
 /*   690 */    24,   25,   26,   27,   28,   29,   30,   49,   50,  106,
 /*   700 */   120,  121,  122,  123,  124,  125,  120,  121,  122,  123,
 /*   710 */   124,  125,  239,  120,  121,  122,  123,  124,  125,  126,
 /*   720 */   127,  128,  201,  202,  178,  132,  133,    5,    6,    7,
 /*   730 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   740 */    18,  117,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   750 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   760 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   770 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   26,
 /*   780 */    45,   49,   50,   43,   24,   25,  240,  241,  242,   49,
 /*   790 */    50,   31,    7,   32,  146,   34,   35,   36,   37,    7,
 /*   800 */   166,   40,   42,   43,   69,   45,   45,   47,   76,   49,
 /*   810 */    50,   57,   54,   48,   56,   30,   24,   25,   26,   65,
 /*   820 */    85,   86,   64,   31,   70,  166,   26,  211,   68,   44,
 /*   830 */    47,  166,   49,   48,   42,   43,  166,  221,   78,   47,
 /*   840 */   166,   49,   50,   97,   90,   99,  100,  182,  183,   49,
 /*   850 */    50,   98,  182,  183,  119,   94,  103,  166,  166,  202,
 /*   860 */    68,   76,   77,   78,  230,  195,  106,  166,   83,  250,
 /*   870 */    78,  106,  107,  166,  182,  183,   91,  116,  204,   96,
 /*   880 */   120,  121,  122,  123,  124,  125,  126,  127,  128,  182,
 /*   890 */   183,  232,  132,  133,  166,  204,  101,  102,  106,  138,
 /*   900 */   235,  236,  237,   44,  239,  204,  145,   48,  178,  239,
 /*   910 */   182,  183,  120,  121,  122,  123,  124,  125,  126,  127,
 /*   920 */   128,    7,  201,  202,  132,  133,  219,  220,   45,  249,
 /*   930 */   238,  239,  166,  205,  166,  166,  208,  166,   24,   25,
 /*   940 */   246,  247,  166,   60,  166,   31,  239,  219,  182,  183,
 /*   950 */   182,  183,   69,  182,  183,  166,   42,   43,  182,  183,
 /*   960 */   166,   47,  166,   49,   50,  106,  107,  239,   85,   86,
 /*   970 */   240,  241,  242,  204,  166,  205,  182,  183,  208,  166,
 /*   980 */   166,  166,   68,  175,  176,  219,  220,  219,  220,  181,
 /*   990 */   219,  220,   78,  204,  186,  219,  220,   43,  166,  166,
 /*  1000 */   166,  166,  119,   49,   50,  239,  166,  239,  166,    7,
 /*  1010 */   239,  166,   43,  219,  166,  239,  182,  183,   49,   50,
 /*  1020 */   106,   98,  182,  183,  182,  183,  103,   49,   50,  166,
 /*  1030 */   182,  183,   35,  239,  120,  121,  122,  123,  124,  125,
 /*  1040 */   126,  127,  128,  230,  196,  166,  132,  133,   51,  204,
 /*  1050 */   254,  166,  166,  219,  166,  111,  112,  166,   61,   62,
 /*  1060 */   166,  166,  230,  230,  166,  166,   69,  182,  183,  166,
 /*  1070 */   182,  183,  222,  239,  259,  166,  182,  183,  238,  239,
 /*  1080 */    78,  239,  166,  204,  166,  182,  183,  239,  166,  254,
 /*  1090 */   204,  182,  183,  166,   39,  166,  197,  166,  182,  183,
 /*  1100 */   182,  183,  204,  166,  182,  183,  166,  166,  166,  182,
 /*  1110 */   183,  182,  183,  182,  183,  166,   59,  254,  166,  182,
 /*  1120 */   183,  166,  182,  183,  239,  230,  205,  239,  166,  208,
 /*  1130 */   166,  182,  183,  239,  182,  183,  166,  182,  183,  197,
 /*  1140 */   207,   78,  239,  166,  182,  183,  182,  183,  239,   92,
 /*  1150 */    95,  218,  182,  183,   91,  239,  166,  239,  166,  182,
 /*  1160 */   183,  239,  205,   49,   50,  208,  239,  166,  239,  166,
 /*  1170 */   239,   43,  182,  183,  182,  183,  239,  209,  205,  239,
 /*  1180 */   166,  208,  166,  182,  183,  182,  183,  205,  239,  166,
 /*  1190 */   208,  239,  137,    7,  239,  140,  182,  183,  182,  183,
 /*  1200 */   166,  239,  166,  239,  166,  182,  183,  166,   44,  239,
 /*  1210 */   205,  166,   48,  208,  223,  224,  239,  222,  182,  183,
 /*  1220 */   182,  183,  222,  182,  183,  210,    7,  182,  183,  239,
 /*  1230 */   166,  239,  104,  166,   44,  166,   50,   44,   48,  166,
 /*  1240 */   239,   48,  239,  166,   85,   86,   77,   78,  166,  182,
 /*  1250 */   183,  182,  183,  239,  166,  239,  166,   44,  166,  182,
 /*  1260 */   183,   48,  239,  166,  182,  183,  166,  166,  166,   50,
 /*  1270 */   182,  183,  166,   49,   50,  239,  166,  239,  166,  213,
 /*  1280 */   239,  166,  182,  183,  239,  226,   44,   44,  182,  183,
 /*  1290 */    48,   48,  182,  183,  182,  183,   44,  182,  183,   44,
 /*  1300 */    48,  226,  166,   48,  166,   44,  239,   44,  239,   48,
 /*  1310 */    44,   48,  213,  255,   48,   44,  239,  166,   44,   48,
 /*  1320 */   255,  239,   48,  166,  166,  185,  166,  239,  166,  166,
 /*  1330 */   226,  166,  166,  166,  166,  210,  166,  166,  245,  239,
 /*  1340 */   166,  212,  210,  166,  166,  239,  166,  166,    9,  239,
 /*  1350 */    43,  239,   43,  234,  239,    5,  200,  117,  213,   41,
 /*  1360 */   188,  134,  187,  252,  203,  142,   41,  251,  172,  234,
 /*  1370 */   172,  172,  187,  172,   63,  188,  203,   84,  187,  203,
 /*  1380 */   191,   84,  203,  200,  200,  188,  194,  192,  194,  187,
 /*  1390 */    84,  184,  184,  109,   84,  213,   43,  243,  134,  244,
 /*  1400 */    43,  187,  187,  260,  115,  110,  114,  113,   46,  174,
 /*  1410 */    45,   43,   36,  169,  168,  165,  228,    4,  165,  170,
 /*  1420 */     3,  217,  177,   43,  177,   66,  215,  227,   43,   82,
 /*  1430 */   214,  228,  227,  216,  228,  213,  227,   43,  228,  227,
 /*  1440 */    66,   81,   76,   38,   44,   76,   76,   39,   94,   43,
 /*  1450 */    39,  102,  118,   90,   42,   84,  105,  141,   48,  144,
 /*  1460 */   141,   84,    1,  143,  118,   14,  105,   14,   14,   14,
 /*  1470 */    50,   90,  108,    1,  139,   43,  104,   84,  137,   96,
 /*  1480 */    42,    7,   91,   82,   43,   66,   43,   43,   66,   85,
 /*  1490 */    43,   52,   66,   86,   58,   98,   44,   48,   48,  104,
 /*  1500 */    44,   44,   43,  107,   44,   43,  108,   44,   44,   43,
 /*  1510 */   108,  108,  125,   78,   44,   50,   48,   48,   47,   44,
 /*  1520 */    44,  105,   44,   44,   43,   48,   44,   60,   43,   96,
 /*  1530 */    44,   48,   43,   96,   44,   43,   14,   44,   43,   33,
 /*  1540 */    44,   43,   38,   44,   44,   43,  104,    1,   47,    0,
};
#define YY_SHIFT_USE_DFLT (1550)
#define YY_SHIFT_COUNT    (427)
#define YY_SHIFT_MIN      (-70)
#define YY_SHIFT_MAX      (1549)
static const short yy_shift_ofst[] = {
 /*     0 */   351,  593,  761,   98,  760,  914,  914,  914,  914,  914,
 /*    10 */   732,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    20 */   785,  785,  735,  732,   -5,   43,   43,  227,  227,  792,
 /*    30 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    40 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    50 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    60 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    70 */   914,  544,  883,  393,   72,  253,  311,  356,  401,  446,
 /*    80 */   491,  517,  543,  569,  722,  722,  722,  722,  722,  722,
 /*    90 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   100 */   748,  722,  278,  666,  666,   11,  167,  167,  167,  185,
 /*   110 */   106,  285,  412,  795,  -70,  -70,  -70,   13, 1550, 1550,
 /*   120 */  1550,  -41,  -41,  997,  997,   23,  604,  604,  648,  239,
 /*   130 */   978,  978,  978,  433,  978,  978,  978,  978,  978,  978,
 /*   140 */   978,  978,  978,  978,  978,  978,  978,  978,  978,  239,
 /*   150 */   978,  978,  978,  978,  795,  130,  130,  130,  130,  130,
 /*   160 */  1550, 1550,  580,  586,  586,  263,  548,  754,  754,  859,
 /*   170 */   302,  385,  553,  606,   52,  758,  740,  800,  783,  783,
 /*   180 */   783,  954,  765,  969,  746,  753,  978,  978,  978,  978,
 /*   190 */   978,  978,  978,  978,  624, 1186, 1186,  978,  978, 1219,
 /*   200 */   624,  978, 1219,  978,  978,  978,  978,  978,  978,  978,
 /*   210 */   944,  978,  978, 1186,  978,   64,  978,  978,  923,  978,
 /*   220 */   300,  923,  978,  978,  978,  978, 1339, 1307, 1309, 1350,
 /*   230 */  1240, 1318, 1318, 1318, 1318, 1227, 1223, 1325, 1240, 1309,
 /*   240 */  1350, 1350, 1325, 1307, 1325, 1325, 1339, 1307, 1311, 1293,
 /*   250 */  1297, 1339, 1307, 1311, 1306, 1306, 1284, 1310, 1284, 1310,
 /*   260 */  1284, 1310, 1284, 1310, 1353, 1264, 1307, 1307, 1357, 1289,
 /*   270 */  1295, 1292, 1294, 1240, 1362, 1365, 1368, 1376, 1376, 1550,
 /*   280 */  1550, 1550, 1055,  535,  322,  348,  399, 1190, 1193,   77,
 /*   290 */  1242, 1243, 1252, 1255, 1261, 1263, 1266, 1114, 1159, 1169,
 /*   300 */  1057, 1063, 1164, 1213, 1271, 1002, 1224, 1128, 1274, 1413,
 /*   310 */  1417, 1359, 1380, 1385, 1347, 1394, 1374, 1366, 1360, 1405,
 /*   320 */  1369, 1370, 1354, 1408, 1400, 1406, 1411, 1349, 1334, 1363,
 /*   330 */  1351, 1371, 1412, 1316, 1410, 1319, 1315, 1320, 1377, 1461,
 /*   340 */  1361, 1346, 1451, 1453, 1454, 1455, 1381, 1420, 1364, 1372,
 /*   350 */  1472, 1335, 1432, 1393, 1341, 1383, 1438, 1474, 1391, 1401,
 /*   360 */  1441, 1419, 1443, 1444, 1422, 1404, 1439, 1407, 1447, 1426,
 /*   370 */  1436, 1452, 1456, 1457, 1449, 1397, 1459, 1460, 1462, 1450,
 /*   380 */  1395, 1463, 1464, 1465, 1398, 1466, 1396, 1468, 1402, 1469,
 /*   390 */  1403, 1470, 1475, 1476, 1416, 1468, 1478, 1471, 1477, 1479,
 /*   400 */  1481, 1467, 1482, 1485, 1433, 1483, 1486, 1489, 1437, 1483,
 /*   410 */  1490, 1492, 1493, 1495, 1496, 1498, 1499, 1387, 1500, 1502,
 /*   420 */  1435, 1442, 1501, 1522, 1504, 1506, 1546, 1549,
};
#define YY_REDUCE_USE_DFLT (-167)
#define YY_REDUCE_COUNT (281)
#define YY_REDUCE_MIN   (-166)
#define YY_REDUCE_MAX   (1253)
static const short yy_reduce_ofst[] = {
 /*     0 */  -115,  -40,  183,  665,  728,  707,  766,  768,  771,  776,
 /*    10 */   -17,  -22,  254,  473,  670,  794,  834,  848,  692,  840,
 /*    20 */   209,  299,  -81,  808,  366,  -39,  207,  546,  730,  842,
 /*    30 */   885,  888,  894,  903,  909,  916,  918,  922,  927,  929,
 /*    40 */   931,  937,  940,  949,  952,  955,  962,  964,  970,  977,
 /*    50 */   990,  992, 1001, 1003, 1014, 1016, 1023, 1036, 1038, 1041,
 /*    60 */  1045, 1067, 1069, 1077, 1082, 1088, 1100, 1106, 1110, 1112,
 /*    70 */  1115,  -56,  -80,  426, -166, -166, -166, -166, -166, -166,
 /*    80 */  -166, -166, -166, -166, -166, -166, -166, -166, -166, -166,
 /*    90 */  -166, -166, -166, -166, -166, -166, -166, -166, -166, -166,
 /*   100 */  -166, -166, -166, -166, -166, -166, -166, -166, -166, -166,
 /*   110 */  -166, -166, -166,  226,  205,  292,  420, -166, -166, -166,
 /*   120 */  -166,  -75,  383,  521,  721,  694,  143,  659,  277,  -20,
 /*   130 */   454,  -47,  674,  770,  691,  701,  769,  789,  845,  879,
 /*   140 */   886,  634,  898,  796,  813,  835,  832,  833,  863,  472,
 /*   150 */   899,  895,  815,  942,  933,  921,  957,  973,  982, 1005,
 /*   160 */   991,  616,   34,   90,  211,  188,  234,  289,  417,  400,
 /*   170 */   410,  437,  456,  657,  619,  680,  778,  814,  850,  995,
 /*   180 */  1000,  891,  400,  941,  968, 1015, 1034, 1064, 1073, 1090,
 /*   190 */  1092, 1097, 1101, 1102, 1066, 1059, 1075, 1136, 1138, 1058,
 /*   200 */  1099, 1151, 1065, 1157, 1158, 1160, 1162, 1163, 1165, 1166,
 /*   210 */  1140, 1167, 1168, 1104, 1170, 1093, 1171, 1174, 1125,  814,
 /*   220 */  1129, 1132, 1177, 1178, 1180, 1181, 1172, 1175, 1119, 1156,
 /*   230 */  1145, 1161, 1173, 1176, 1179, 1111, 1116, 1196, 1182, 1135,
 /*   240 */  1183, 1184, 1198, 1185, 1199, 1201, 1187, 1191, 1192, 1189,
 /*   250 */  1195, 1197, 1202, 1194, 1207, 1208, 1188, 1200, 1203, 1205,
 /*   260 */  1206, 1209, 1210, 1212, 1154, 1155, 1214, 1215, 1143, 1204,
 /*   270 */  1217, 1211, 1216, 1222, 1235, 1244, 1246, 1250, 1253, 1245,
 /*   280 */  1247, 1249,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1225, 1207, 1207, 1254, 1207, 1154, 1154, 1154, 1154, 1154,
 /*    10 */   968, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1112, 1112,
 /*    20 */   968,  968, 1207,  968, 1036, 1067, 1067,  981,  981, 1254,
 /*    30 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*    40 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*    50 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*    60 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*    70 */  1254, 1254, 1207, 1040, 1073, 1254, 1254, 1254, 1155, 1156,
 /*    80 */  1254, 1254, 1109, 1254, 1181, 1084, 1083, 1082, 1081, 1050,
 /*    90 */  1079, 1071, 1075, 1155, 1151, 1152, 1150, 1113, 1108, 1156,
 /*   100 */  1254, 1074, 1122, 1135, 1121, 1131, 1141, 1132, 1124, 1123,
 /*   110 */  1125, 1126, 1127, 1254,  987,  987,  987, 1128, 1138, 1137,
 /*   120 */  1136, 1254, 1254, 1254, 1254, 1161, 1254, 1254, 1254, 1007,
 /*   130 */  1254, 1254, 1254, 1207, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   140 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1007,
 /*   150 */  1254, 1254, 1254, 1254, 1254, 1207, 1207, 1207, 1207, 1207,
 /*   160 */  1040, 1031, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   170 */  1036, 1254, 1254, 1254, 1254, 1175, 1254, 1254, 1036, 1036,
 /*   180 */  1036, 1254, 1038, 1254, 1020, 1030, 1254, 1254, 1254, 1254,
 /*   190 */  1254, 1254, 1254, 1254, 1078, 1052, 1052, 1254, 1254, 1252,
 /*   200 */  1078, 1254, 1252, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   210 */  1067, 1254, 1254, 1052, 1254, 1153, 1254, 1254, 1030, 1254,
 /*   220 */  1037, 1030, 1254, 1254, 1254, 1254,  993, 1162, 1089, 1010,
 /*   230 */  1078, 1017, 1017, 1017, 1017, 1180, 1179,  959, 1078, 1089,
 /*   240 */  1010, 1010,  959, 1162,  959,  959,  993, 1162, 1001,  984,
 /*   250 */   983,  993, 1162, 1001, 1008, 1008, 1056, 1051, 1056, 1051,
 /*   260 */  1056, 1051, 1056, 1051, 1157, 1254, 1162, 1162, 1254, 1072,
 /*   270 */  1057, 1070, 1068, 1078, 1254, 1232, 1254, 1228, 1228, 1236,
 /*   280 */  1236,  962, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   290 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   300 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1095, 1254, 1254,
 /*   310 */   949, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   320 */  1254, 1254, 1197, 1254, 1254, 1167, 1254, 1254, 1254, 1254,
 /*   330 */  1254, 1254, 1254, 1254, 1178, 1177, 1254, 1254, 1254, 1254,
 /*   340 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1251,
 /*   350 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   360 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   370 */  1254, 1254, 1254, 1254, 1254, 1022, 1254, 1254, 1254, 1242,
 /*   380 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1069, 1254, 1058,
 /*   390 */  1254, 1254, 1254, 1254, 1254, 1249, 1254, 1254, 1254, 1254,
 /*   400 */  1254, 1254, 1254, 1254, 1254, 1209, 1254, 1254, 1254, 1208,
 /*   410 */  1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254, 1254,
 /*   420 */  1254, 1254, 1254, 1254,  953, 1254, 1254, 1254,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "ANY",         
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "UPDATE",        "DELETE",        "SIMPLE",      
  "PARTIAL",       "FULL",          "SET",           "DEFERRABLE",  
  "IMMEDIATE",     "FOREIGN",       "DROP",          "VIEW",        
  "AS",            "UNION",         "ALL",           "EXCEPT",      
  "INTERSECT",     "SELECT",        "VALUES",        "DISTINCT",    
  "DOT",           "FROM",          "JOIN_KW",       "JOIN",        
  "BY",            "USING",         "ORDER",         "ASC",         
  "DESC",          "GROUP",         "HAVING",        "LIMIT",       
  "TRUNCATE",      "WHERE",         "INTO",          "INSERT",      
  "FLOAT",         "BLOB",          "FALSE",         "TRUE",        
  "UNKNOWN",       "INTEGER",       "VARIABLE",      "CAST",        
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "PRAGMA",        "BEGIN",       
  "TRIGGER",       "OF",            "FOR",           "EACH",        
  "ROW",           "ALTER",         "RECURSIVE",     "TEXT",        
  "STRING_KW",     "SCALAR",        "BOOL",          "BOOLEAN",     
  "VARBINARY",     "VARCHAR",       "NUMBER",        "DOUBLE",      
  "INT",           "INTEGER_KW",    "UNSIGNED",      "error",       
  "input",         "ecmd",          "explain",       "cmdx",        
  "cmd",           "savepoint_opt",  "nm",            "create_table",
  "create_table_args",  "with_opts",     "create_table_end",  "createkw",    
  "ifnotexists",   "columnlist",    "engine_opts",   "tcons",       
  "columnname",    "carglist",      "autoinc",       "typedef",     
  "ccons",         "cconsname",     "term",          "expr",        
  "onconf",        "sortorder",     "check_constraint_def",  "eidlist_opt", 
  "matcharg",      "refargs",       "defer_subclause",  "refact_update",
  "refact_delete",  "refact",        "init_deferred_pred_opt",  "col_list_with_autoinc",
  "sortlist",      "eidlist",       "defer_subclause_opt",  "index_onconf",
  "orconf",        "resolvetype",   "raisetype",     "ifexists",    
  "fullname",      "select",        "selectnowith",  "oneselect",   
  "with",          "multiselect_op",  "distinct",      "selcollist",  
  "from",          "where_opt",     "groupby_opt",   "having_opt",  
  "orderby_opt",   "limit_opt",     "values",        "nexprlist",   
  "exprlist",      "sclp",          "as",            "seltablist",  
  "stl_prefix",    "joinop",        "indexed_opt",   "on_opt",      
  "using_opt",     "join_nm",       "idlist",        "enable",      
  "setlist",       "insert_cmd",    "idlist_opt",    "trim_operands",
  "trim_from_clause",  "trim_specification",  "expr_optional",  "type_func",   
  "likeop",        "between_op",    "in_op",         "paren_exprlist",
  "case_exprlist",  "case_else",     "uniqueflag",    "trigger_decl",
  "trigger_cmd_list",  "trigger_time",  "trigger_event",  "foreach_clause",
  "when_clause",   "trigger_cmd",   "trnm",          "tridxby",     
  "alter_table_start",  "alter_add_constraint",  "unique_spec",   "wqlist",      
  "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "columnlist ::= columnlist COMMA columnname carglist autoinc",
 /*  17 */ "columnlist ::= columnname carglist autoinc",
 /*  18 */ "columnname ::= nm typedef",
 /*  19 */ "nm ::= ID|INDEXED",
 /*  20 */ "cconsname ::= CONSTRAINT nm",
 /*  21 */ "cconsname ::=",
 /*  22 */ "ccons ::= DEFAULT term",
 /*  23 */ "ccons ::= DEFAULT LP expr RP",
 /*  24 */ "ccons ::= DEFAULT PLUS term",
 /*  25 */ "ccons ::= DEFAULT MINUS term",
 /*  26 */ "ccons ::= NULL onconf",
 /*  27 */ "ccons ::= NOT NULL onconf",
 /*  28 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  29 */ "ccons ::= cconsname UNIQUE",
 /*  30 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  31 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  32 */ "ccons ::= defer_subclause",
 /*  33 */ "ccons ::= COLLATE ID|INDEXED",
 /*  34 */ "autoinc ::=",
 /*  35 */ "autoinc ::= AUTOINCR",
 /*  36 */ "refargs ::= refact_update",
 /*  37 */ "refargs ::= refact_delete",
 /*  38 */ "refargs ::= refact_delete refact_update",
 /*  39 */ "refargs ::= refact_update refact_delete",
 /*  40 */ "refargs ::=",
 /*  41 */ "refact_update ::= ON UPDATE refact",
 /*  42 */ "refact_delete ::= ON DELETE refact",
 /*  43 */ "matcharg ::= MATCH SIMPLE",
 /*  44 */ "matcharg ::= MATCH PARTIAL",
 /*  45 */ "matcharg ::= MATCH FULL",
 /*  46 */ "matcharg ::=",
 /*  47 */ "refact ::= SET NULL",
 /*  48 */ "refact ::= SET DEFAULT",
 /*  49 */ "refact ::= CASCADE",
 /*  50 */ "refact ::= RESTRICT",
 /*  51 */ "refact ::= NO ACTION",
 /*  52 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  54 */ "init_deferred_pred_opt ::=",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  56 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  57 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  58 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  59 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  60 */ "defer_subclause_opt ::=",
 /*  61 */ "onconf ::=",
 /*  62 */ "onconf ::= ON CONFLICT resolvetype",
 /*  63 */ "orconf ::=",
 /*  64 */ "orconf ::= OR resolvetype",
 /*  65 */ "resolvetype ::= IGNORE",
 /*  66 */ "resolvetype ::= REPLACE",
 /*  67 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  68 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  69 */ "ifexists ::= IF EXISTS",
 /*  70 */ "ifexists ::=",
 /*  71 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  72 */ "cmd ::= select",
 /*  73 */ "select ::= with selectnowith",
 /*  74 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  75 */ "multiselect_op ::= UNION",
 /*  76 */ "multiselect_op ::= UNION ALL",
 /*  77 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  78 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  79 */ "values ::= VALUES LP nexprlist RP",
 /*  80 */ "values ::= values COMMA LP exprlist RP",
 /*  81 */ "distinct ::= DISTINCT",
 /*  82 */ "distinct ::= ALL",
 /*  83 */ "distinct ::=",
 /*  84 */ "sclp ::=",
 /*  85 */ "selcollist ::= sclp expr as",
 /*  86 */ "selcollist ::= sclp STAR",
 /*  87 */ "selcollist ::= sclp nm DOT STAR",
 /*  88 */ "as ::= AS nm",
 /*  89 */ "as ::=",
 /*  90 */ "from ::=",
 /*  91 */ "from ::= FROM seltablist",
 /*  92 */ "stl_prefix ::= seltablist joinop",
 /*  93 */ "stl_prefix ::=",
 /*  94 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  97 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  98 */ "fullname ::= nm",
 /*  99 */ "joinop ::= COMMA|JOIN",
 /* 100 */ "joinop ::= JOIN_KW JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 102 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 103 */ "on_opt ::= ON expr",
 /* 104 */ "on_opt ::=",
 /* 105 */ "indexed_opt ::=",
 /* 106 */ "indexed_opt ::= INDEXED BY nm",
 /* 107 */ "indexed_opt ::= NOT INDEXED",
 /* 108 */ "using_opt ::= USING LP idlist RP",
 /* 109 */ "using_opt ::=",
 /* 110 */ "orderby_opt ::=",
 /* 111 */ "orderby_opt ::= ORDER BY sortlist",
 /* 112 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 113 */ "sortlist ::= expr sortorder",
 /* 114 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 115 */ "col_list_with_autoinc ::= expr autoinc",
 /* 116 */ "enable ::= ENABLE",
 /* 117 */ "enable ::= DISABLE",
 /* 118 */ "sortorder ::= ASC",
 /* 119 */ "sortorder ::= DESC",
 /* 120 */ "sortorder ::=",
 /* 121 */ "groupby_opt ::=",
 /* 122 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 123 */ "having_opt ::=",
 /* 124 */ "having_opt ::= HAVING expr",
 /* 125 */ "limit_opt ::=",
 /* 126 */ "limit_opt ::= LIMIT expr",
 /* 127 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 128 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 129 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 130 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 131 */ "where_opt ::=",
 /* 132 */ "where_opt ::= WHERE expr",
 /* 133 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 134 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 135 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 136 */ "setlist ::= nm EQ expr",
 /* 137 */ "setlist ::= LP idlist RP EQ expr",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 139 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 140 */ "insert_cmd ::= INSERT orconf",
 /* 141 */ "insert_cmd ::= REPLACE",
 /* 142 */ "idlist_opt ::=",
 /* 143 */ "idlist_opt ::= LP idlist RP",
 /* 144 */ "idlist ::= idlist COMMA nm",
 /* 145 */ "idlist ::= nm",
 /* 146 */ "expr ::= LP expr RP",
 /* 147 */ "term ::= NULL",
 /* 148 */ "expr ::= ID|INDEXED",
 /* 149 */ "expr ::= JOIN_KW",
 /* 150 */ "expr ::= nm DOT nm",
 /* 151 */ "term ::= FLOAT|BLOB",
 /* 152 */ "term ::= STRING",
 /* 153 */ "term ::= FALSE",
 /* 154 */ "term ::= TRUE",
 /* 155 */ "term ::= UNKNOWN",
 /* 156 */ "term ::= INTEGER",
 /* 157 */ "expr ::= VARIABLE",
 /* 158 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 159 */ "expr ::= CAST LP expr AS typedef RP",
 /* 160 */ "expr ::= TRIM LP trim_operands RP",
 /* 161 */ "trim_operands ::= trim_from_clause expr",
 /* 162 */ "trim_operands ::= expr",
 /* 163 */ "trim_from_clause ::= expr FROM",
 /* 164 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 165 */ "expr_optional ::=",
 /* 166 */ "expr_optional ::= expr",
 /* 167 */ "trim_specification ::= LEADING",
 /* 168 */ "trim_specification ::= TRAILING",
 /* 169 */ "trim_specification ::= BOTH",
 /* 170 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 171 */ "expr ::= type_func LP distinct exprlist RP",
 /* 172 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 173 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 174 */ "expr ::= expr AND expr",
 /* 175 */ "expr ::= expr OR expr",
 /* 176 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 177 */ "expr ::= expr EQ|NE expr",
 /* 178 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 179 */ "expr ::= expr PLUS|MINUS expr",
 /* 180 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 181 */ "expr ::= expr CONCAT expr",
 /* 182 */ "likeop ::= LIKE_KW|MATCH",
 /* 183 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 184 */ "expr ::= expr likeop expr",
 /* 185 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 186 */ "expr ::= expr IS NULL",
 /* 187 */ "expr ::= expr IS NOT NULL",
 /* 188 */ "expr ::= NOT expr",
 /* 189 */ "expr ::= BITNOT expr",
 /* 190 */ "expr ::= MINUS expr",
 /* 191 */ "expr ::= PLUS expr",
 /* 192 */ "between_op ::= BETWEEN",
 /* 193 */ "between_op ::= NOT BETWEEN",
 /* 194 */ "expr ::= expr between_op expr AND expr",
 /* 195 */ "in_op ::= IN",
 /* 196 */ "in_op ::= NOT IN",
 /* 197 */ "expr ::= expr in_op LP exprlist RP",
 /* 198 */ "expr ::= LP select RP",
 /* 199 */ "expr ::= expr in_op LP select RP",
 /* 200 */ "expr ::= expr in_op nm paren_exprlist",
 /* 201 */ "expr ::= EXISTS LP select RP",
 /* 202 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 203 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 204 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 205 */ "case_else ::= ELSE expr",
 /* 206 */ "case_else ::=",
 /* 207 */ "exprlist ::=",
 /* 208 */ "nexprlist ::= nexprlist COMMA expr",
 /* 209 */ "nexprlist ::= expr",
 /* 210 */ "paren_exprlist ::=",
 /* 211 */ "paren_exprlist ::= LP exprlist RP",
 /* 212 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 213 */ "uniqueflag ::= UNIQUE",
 /* 214 */ "uniqueflag ::=",
 /* 215 */ "eidlist_opt ::=",
 /* 216 */ "eidlist_opt ::= LP eidlist RP",
 /* 217 */ "eidlist ::= eidlist COMMA nm",
 /* 218 */ "eidlist ::= nm",
 /* 219 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 220 */ "cmd ::= PRAGMA nm",
 /* 221 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 222 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 223 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 224 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 225 */ "trigger_time ::= BEFORE",
 /* 226 */ "trigger_time ::= AFTER",
 /* 227 */ "trigger_time ::= INSTEAD OF",
 /* 228 */ "trigger_time ::=",
 /* 229 */ "trigger_event ::= DELETE|INSERT",
 /* 230 */ "trigger_event ::= UPDATE",
 /* 231 */ "trigger_event ::= UPDATE OF idlist",
 /* 232 */ "foreach_clause ::=",
 /* 233 */ "when_clause ::=",
 /* 234 */ "when_clause ::= WHEN expr",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 237 */ "trnm ::= nm DOT nm",
 /* 238 */ "tridxby ::= INDEXED BY nm",
 /* 239 */ "tridxby ::= NOT INDEXED",
 /* 240 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 241 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 242 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 243 */ "trigger_cmd ::= select",
 /* 244 */ "expr ::= RAISE LP IGNORE RP",
 /* 245 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 246 */ "raisetype ::= ROLLBACK",
 /* 247 */ "raisetype ::= ABORT",
 /* 248 */ "raisetype ::= FAIL",
 /* 249 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 250 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 251 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 252 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 253 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 254 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 255 */ "unique_spec ::= UNIQUE",
 /* 256 */ "unique_spec ::= PRIMARY KEY",
 /* 257 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 258 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 259 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 260 */ "with ::=",
 /* 261 */ "with ::= WITH wqlist",
 /* 262 */ "with ::= WITH RECURSIVE wqlist",
 /* 263 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 264 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 265 */ "typedef ::= TEXT",
 /* 266 */ "typedef ::= STRING_KW",
 /* 267 */ "typedef ::= SCALAR",
 /* 268 */ "typedef ::= BOOL",
 /* 269 */ "typedef ::= BOOLEAN",
 /* 270 */ "typedef ::= VARBINARY",
 /* 271 */ "char_len ::= LP INTEGER RP",
 /* 272 */ "typedef ::= VARCHAR char_len",
 /* 273 */ "number_typedef ::= NUMBER",
 /* 274 */ "number_typedef ::= DOUBLE",
 /* 275 */ "number_typedef ::= INT|INTEGER_KW",
 /* 276 */ "number_typedef ::= UNSIGNED",
 /* 277 */ "input ::= ecmd",
 /* 278 */ "explain ::=",
 /* 279 */ "cmdx ::= cmd",
 /* 280 */ "savepoint_opt ::= SAVEPOINT",
 /* 281 */ "savepoint_opt ::=",
 /* 282 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 283 */ "create_table_args ::= LP columnlist RP",
 /* 284 */ "with_opts ::= WITH engine_opts",
 /* 285 */ "with_opts ::=",
 /* 286 */ "columnlist ::= columnlist COMMA tcons",
 /* 287 */ "columnlist ::= tcons",
 /* 288 */ "carglist ::= carglist ccons",
 /* 289 */ "carglist ::=",
 /* 290 */ "ccons ::= check_constraint_def",
 /* 291 */ "tcons ::= check_constraint_def",
 /* 292 */ "defer_subclause_opt ::= defer_subclause",
 /* 293 */ "resolvetype ::= raisetype",
 /* 294 */ "selectnowith ::= oneselect",
 /* 295 */ "oneselect ::= values",
 /* 296 */ "sclp ::= selcollist COMMA",
 /* 297 */ "as ::= ID|STRING",
 /* 298 */ "join_nm ::= ID|INDEXED",
 /* 299 */ "join_nm ::= JOIN_KW",
 /* 300 */ "expr ::= term",
 /* 301 */ "type_func ::= CHAR",
 /* 302 */ "exprlist ::= nexprlist",
 /* 303 */ "foreach_clause ::= FOR EACH ROW",
 /* 304 */ "trnm ::= nm",
 /* 305 */ "tridxby ::=",
 /* 306 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 182: /* term */
    case 183: /* expr */
{
#line 953 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy382).pExpr, false);
#line 1570 "parse.c"
}
      break;
    case 187: /* eidlist_opt */
    case 195: /* col_list_with_autoinc */
    case 196: /* sortlist */
    case 197: /* eidlist */
    case 211: /* selcollist */
    case 214: /* groupby_opt */
    case 216: /* orderby_opt */
    case 219: /* nexprlist */
    case 220: /* exprlist */
    case 221: /* sclp */
    case 232: /* setlist */
    case 243: /* paren_exprlist */
    case 244: /* case_exprlist */
{
#line 1507 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy338));
#line 1589 "parse.c"
}
      break;
    case 204: /* fullname */
    case 212: /* from */
    case 223: /* seltablist */
    case 224: /* stl_prefix */
{
#line 702 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy39));
#line 1599 "parse.c"
}
      break;
    case 205: /* select */
    case 206: /* selectnowith */
    case 207: /* oneselect */
    case 218: /* values */
{
#line 464 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy479));
#line 1609 "parse.c"
}
      break;
    case 208: /* with */
    case 259: /* wqlist */
{
#line 1780 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy231));
#line 1617 "parse.c"
}
      break;
    case 213: /* where_opt */
    case 215: /* having_opt */
    case 227: /* on_opt */
    case 245: /* case_else */
    case 252: /* when_clause */
{
#line 862 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy366), false);
#line 1628 "parse.c"
}
      break;
    case 228: /* using_opt */
    case 230: /* idlist */
    case 234: /* idlist_opt */
{
#line 745 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy40));
#line 1637 "parse.c"
}
      break;
    case 235: /* trim_operands */
    case 236: /* trim_from_clause */
{
#line 1124 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy179));
#line 1645 "parse.c"
}
      break;
    case 238: /* expr_optional */
{
#line 1155 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy443), false);
#line 1652 "parse.c"
}
      break;
    case 248: /* trigger_cmd_list */
    case 253: /* trigger_cmd */
{
#line 1600 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy255));
#line 1660 "parse.c"
}
      break;
    case 250: /* trigger_event */
{
#line 1581 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy434).b);
#line 1667 "parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1843 "parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 161, 3 },
  { 161, 1 },
  { 162, 1 },
  { 162, 3 },
  { 164, 2 },
  { 164, 1 },
  { 164, 1 },
  { 164, 2 },
  { 164, 3 },
  { 164, 4 },
  { 167, 4 },
  { 171, 1 },
  { 172, 0 },
  { 172, 3 },
  { 174, 3 },
  { 170, 0 },
  { 173, 5 },
  { 173, 3 },
  { 176, 2 },
  { 166, 1 },
  { 181, 2 },
  { 181, 0 },
  { 180, 2 },
  { 180, 4 },
  { 180, 3 },
  { 180, 3 },
  { 180, 2 },
  { 180, 3 },
  { 180, 4 },
  { 180, 2 },
  { 186, 5 },
  { 180, 6 },
  { 180, 1 },
  { 180, 2 },
  { 178, 0 },
  { 178, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 2 },
  { 189, 2 },
  { 189, 0 },
  { 191, 3 },
  { 192, 3 },
  { 188, 2 },
  { 188, 2 },
  { 188, 2 },
  { 188, 0 },
  { 193, 2 },
  { 193, 2 },
  { 193, 1 },
  { 193, 1 },
  { 193, 2 },
  { 190, 3 },
  { 190, 2 },
  { 194, 0 },
  { 194, 2 },
  { 194, 2 },
  { 175, 6 },
  { 175, 5 },
  { 175, 12 },
  { 198, 0 },
  { 184, 0 },
  { 184, 3 },
  { 200, 0 },
  { 200, 2 },
  { 201, 1 },
  { 201, 1 },
  { 164, 4 },
  { 164, 4 },
  { 203, 2 },
  { 203, 0 },
  { 164, 7 },
  { 164, 1 },
  { 205, 2 },
  { 206, 3 },
  { 209, 1 },
  { 209, 2 },
  { 209, 1 },
  { 207, 9 },
  { 218, 4 },
  { 218, 5 },
  { 210, 1 },
  { 210, 1 },
  { 210, 0 },
  { 221, 0 },
  { 211, 3 },
  { 211, 2 },
  { 211, 4 },
  { 222, 2 },
  { 222, 0 },
  { 212, 0 },
  { 212, 2 },
  { 224, 2 },
  { 224, 0 },
  { 223, 6 },
  { 223, 8 },
  { 223, 7 },
  { 223, 7 },
  { 204, 1 },
  { 225, 1 },
  { 225, 2 },
  { 225, 3 },
  { 225, 4 },
  { 227, 2 },
  { 227, 0 },
  { 226, 0 },
  { 226, 3 },
  { 226, 2 },
  { 228, 4 },
  { 228, 0 },
  { 216, 0 },
  { 216, 3 },
  { 196, 4 },
  { 196, 2 },
  { 195, 4 },
  { 195, 2 },
  { 231, 1 },
  { 231, 1 },
  { 185, 1 },
  { 185, 1 },
  { 185, 0 },
  { 214, 0 },
  { 214, 3 },
  { 215, 0 },
  { 215, 2 },
  { 217, 0 },
  { 217, 2 },
  { 217, 4 },
  { 217, 4 },
  { 164, 6 },
  { 164, 3 },
  { 213, 0 },
  { 213, 2 },
  { 164, 8 },
  { 232, 5 },
  { 232, 7 },
  { 232, 3 },
  { 232, 5 },
  { 164, 6 },
  { 164, 7 },
  { 233, 2 },
  { 233, 1 },
  { 234, 0 },
  { 234, 3 },
  { 230, 3 },
  { 230, 1 },
  { 183, 3 },
  { 182, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 3 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 183, 1 },
  { 183, 3 },
  { 183, 6 },
  { 183, 4 },
  { 235, 2 },
  { 235, 1 },
  { 236, 2 },
  { 236, 3 },
  { 238, 0 },
  { 238, 1 },
  { 237, 1 },
  { 237, 1 },
  { 237, 1 },
  { 183, 5 },
  { 183, 5 },
  { 183, 4 },
  { 183, 5 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 183, 3 },
  { 240, 1 },
  { 240, 2 },
  { 183, 3 },
  { 183, 5 },
  { 183, 3 },
  { 183, 4 },
  { 183, 2 },
  { 183, 2 },
  { 183, 2 },
  { 183, 2 },
  { 241, 1 },
  { 241, 2 },
  { 183, 5 },
  { 242, 1 },
  { 242, 2 },
  { 183, 5 },
  { 183, 3 },
  { 183, 5 },
  { 183, 4 },
  { 183, 4 },
  { 183, 5 },
  { 244, 5 },
  { 244, 4 },
  { 245, 2 },
  { 245, 0 },
  { 220, 0 },
  { 219, 3 },
  { 219, 1 },
  { 243, 0 },
  { 243, 3 },
  { 164, 10 },
  { 246, 1 },
  { 246, 0 },
  { 187, 0 },
  { 187, 3 },
  { 197, 3 },
  { 197, 1 },
  { 164, 6 },
  { 164, 2 },
  { 164, 5 },
  { 164, 7 },
  { 164, 5 },
  { 247, 9 },
  { 249, 1 },
  { 249, 1 },
  { 249, 2 },
  { 249, 0 },
  { 250, 1 },
  { 250, 1 },
  { 250, 3 },
  { 251, 0 },
  { 252, 0 },
  { 252, 2 },
  { 248, 3 },
  { 248, 2 },
  { 254, 3 },
  { 255, 3 },
  { 255, 2 },
  { 253, 7 },
  { 253, 5 },
  { 253, 5 },
  { 253, 1 },
  { 183, 4 },
  { 183, 6 },
  { 202, 1 },
  { 202, 1 },
  { 202, 1 },
  { 164, 4 },
  { 256, 3 },
  { 257, 4 },
  { 164, 12 },
  { 164, 5 },
  { 164, 5 },
  { 258, 1 },
  { 258, 2 },
  { 164, 4 },
  { 164, 6 },
  { 164, 5 },
  { 208, 0 },
  { 208, 2 },
  { 208, 3 },
  { 259, 6 },
  { 259, 8 },
  { 179, 1 },
  { 179, 1 },
  { 179, 1 },
  { 179, 1 },
  { 179, 1 },
  { 179, 1 },
  { 260, 3 },
  { 179, 2 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 261, 1 },
  { 160, 1 },
  { 162, 0 },
  { 163, 1 },
  { 165, 1 },
  { 165, 0 },
  { 164, 4 },
  { 168, 3 },
  { 169, 2 },
  { 169, 0 },
  { 173, 3 },
  { 173, 1 },
  { 177, 2 },
  { 177, 0 },
  { 180, 1 },
  { 175, 1 },
  { 198, 1 },
  { 201, 1 },
  { 206, 1 },
  { 207, 1 },
  { 221, 2 },
  { 222, 1 },
  { 229, 1 },
  { 229, 1 },
  { 183, 1 },
  { 239, 1 },
  { 220, 1 },
  { 251, 3 },
  { 254, 1 },
  { 255, 0 },
  { 179, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2293 "parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2301 "parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2306 "parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2311 "parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2316 "parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2321 "parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2326 "parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2333 "parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2340 "parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2347 "parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy116);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2356 "parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 187 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2361 "parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 34: /* autoinc ::= */ yytestcase(yyruleno==34);
      case 54: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==54);
      case 60: /* defer_subclause_opt ::= */ yytestcase(yyruleno==60);
      case 70: /* ifexists ::= */ yytestcase(yyruleno==70);
      case 83: /* distinct ::= */ yytestcase(yyruleno==83);
#line 190 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy116 = 0;}
#line 2371 "parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 191 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy116 = 1;}
#line 2376 "parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 198 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2397 "parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 216 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2402 "parse.c"
        break;
      case 16: /* columnlist ::= columnlist COMMA columnname carglist autoinc */
      case 17: /* columnlist ::= columnname carglist autoinc */ yytestcase(yyruleno==17);
#line 229 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_table_def.new_space->def->field_count - 1;
  if (yymsp[0].minor.yy116 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
}
#line 2412 "parse.c"
        break;
      case 18: /* columnname ::= nm typedef */
#line 241 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sqlAddColumn(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy518);}
#line 2417 "parse.c"
        break;
      case 19: /* nm ::= ID|INDEXED */
#line 276 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2428 "parse.c"
        break;
      case 20: /* cconsname ::= CONSTRAINT nm */
#line 290 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy503 = yymsp[0].minor.yy0; }
#line 2433 "parse.c"
        break;
      case 21: /* cconsname ::= */
#line 291 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy503 = Token_nil; }
#line 2438 "parse.c"
        break;
      case 22: /* ccons ::= DEFAULT term */
      case 24: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==24);
#line 292 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy382);}
#line 2444 "parse.c"
        break;
      case 23: /* ccons ::= DEFAULT LP expr RP */
#line 293 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy382);}
#line 2449 "parse.c"
        break;
      case 25: /* ccons ::= DEFAULT MINUS term */
#line 295 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy382.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy382.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2460 "parse.c"
        break;
      case 26: /* ccons ::= NULL onconf */
#line 306 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy116 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy116);
}
#line 2470 "parse.c"
        break;
      case 27: /* ccons ::= NOT NULL onconf */
#line 312 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy116);}
#line 2475 "parse.c"
        break;
      case 28: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 313 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy503, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy116, false);
  sqlAddPrimaryKey(pParse);
}
#line 2484 "parse.c"
        break;
      case 29: /* ccons ::= cconsname UNIQUE */
#line 318 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy503, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2494 "parse.c"
        break;
      case 30: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 327 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy503, &yymsp[-1].minor.yy382);
  sql_create_check_contraint(pParse);
}
#line 2502 "parse.c"
        break;
      case 31: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 332 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy503, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy338, yymsp[-1].minor.yy116, yymsp[0].minor.yy116,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2511 "parse.c"
        break;
      case 32: /* ccons ::= defer_subclause */
#line 337 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy116);}
#line 2516 "parse.c"
        break;
      case 33: /* ccons ::= COLLATE ID|INDEXED */
#line 338 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2521 "parse.c"
        break;
      case 35: /* autoinc ::= AUTOINCR */
#line 343 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = 1;}
#line 2526 "parse.c"
        break;
      case 36: /* refargs ::= refact_update */
#line 351 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yylhsminor.yy116 = (yymsp[0].minor.yy116 << 8); }
#line 2531 "parse.c"
  yymsp[0].minor.yy116 = yylhsminor.yy116;
        break;
      case 37: /* refargs ::= refact_delete */
#line 352 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yylhsminor.yy116 = yymsp[0].minor.yy116; }
#line 2537 "parse.c"
  yymsp[0].minor.yy116 = yylhsminor.yy116;
        break;
      case 38: /* refargs ::= refact_delete refact_update */
#line 353 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yylhsminor.yy116 = (yymsp[0].minor.yy116 << 8) | (yymsp[-1].minor.yy116) ; }
#line 2543 "parse.c"
  yymsp[-1].minor.yy116 = yylhsminor.yy116;
        break;
      case 39: /* refargs ::= refact_update refact_delete */
#line 354 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yylhsminor.yy116 = (yymsp[-1].minor.yy116 << 8) | (yymsp[0].minor.yy116) ; }
#line 2549 "parse.c"
  yymsp[-1].minor.yy116 = yylhsminor.yy116;
        break;
      case 40: /* refargs ::= */
#line 355 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy116 = 0; }
#line 2555 "parse.c"
        break;
      case 41: /* refact_update ::= ON UPDATE refact */
      case 42: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==42);
#line 358 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-2].minor.yy116 = yymsp[0].minor.yy116; }
#line 2561 "parse.c"
        break;
      case 43: /* matcharg ::= MATCH SIMPLE */
#line 363 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_MATCH_SIMPLE; }
#line 2566 "parse.c"
        break;
      case 44: /* matcharg ::= MATCH PARTIAL */
#line 364 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_MATCH_PARTIAL; }
#line 2571 "parse.c"
        break;
      case 45: /* matcharg ::= MATCH FULL */
#line 365 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_MATCH_FULL; }
#line 2576 "parse.c"
        break;
      case 46: /* matcharg ::= */
#line 366 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy116 = FKEY_MATCH_SIMPLE; }
#line 2581 "parse.c"
        break;
      case 47: /* refact ::= SET NULL */
#line 369 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_ACTION_SET_NULL; }
#line 2586 "parse.c"
        break;
      case 48: /* refact ::= SET DEFAULT */
#line 370 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_ACTION_SET_DEFAULT; }
#line 2591 "parse.c"
        break;
      case 49: /* refact ::= CASCADE */
#line 371 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = FKEY_ACTION_CASCADE; }
#line 2596 "parse.c"
        break;
      case 50: /* refact ::= RESTRICT */
#line 372 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = FKEY_ACTION_RESTRICT; }
#line 2601 "parse.c"
        break;
      case 51: /* refact ::= NO ACTION */
#line 373 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = FKEY_NO_ACTION; }
#line 2606 "parse.c"
        break;
      case 52: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 375 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy116 = 0;}
#line 2611 "parse.c"
        break;
      case 53: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 64: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==64);
      case 140: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==140);
#line 376 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy116 = yymsp[0].minor.yy116;}
#line 2618 "parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 69: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==69);
      case 193: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==193);
      case 196: /* in_op ::= NOT IN */ yytestcase(yyruleno==196);
#line 379 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy116 = 1;}
#line 2626 "parse.c"
        break;
      case 56: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 380 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy116 = 0;}
#line 2631 "parse.c"
        break;
      case 57: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 382 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy503, yymsp[-1].minor.yy338,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2640 "parse.c"
        break;
      case 58: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 387 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy503, yymsp[-1].minor.yy338,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2650 "parse.c"
        break;
      case 59: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 395 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy503, yymsp[-7].minor.yy338, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy338, yymsp[-2].minor.yy116, yymsp[-1].minor.yy116, yymsp[0].minor.yy116);
  sql_create_foreign_key(pParse);
}
#line 2658 "parse.c"
        break;
      case 61: /* onconf ::= */
#line 410 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy116 = ON_CONFLICT_ACTION_ABORT;}
#line 2663 "parse.c"
        break;
      case 62: /* onconf ::= ON CONFLICT resolvetype */
#line 411 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy116 = yymsp[0].minor.yy116;}
#line 2668 "parse.c"
        break;
      case 63: /* orconf ::= */
#line 412 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy116 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2673 "parse.c"
        break;
      case 65: /* resolvetype ::= IGNORE */
#line 415 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = ON_CONFLICT_ACTION_IGNORE;}
#line 2678 "parse.c"
        break;
      case 66: /* resolvetype ::= REPLACE */
      case 141: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==141);
#line 416 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = ON_CONFLICT_ACTION_REPLACE;}
#line 2684 "parse.c"
        break;
      case 67: /* cmd ::= DROP TABLE ifexists fullname */
#line 421 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy39, &t, yymsp[-1].minor.yy116);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2694 "parse.c"
        break;
      case 68: /* cmd ::= DROP VIEW ifexists fullname */
#line 428 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy39, &t, yymsp[-1].minor.yy116);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2704 "parse.c"
        break;
      case 71: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 442 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy338, yymsp[0].minor.yy479, yymsp[-4].minor.yy116);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy479);
  }
}
#line 2717 "parse.c"
        break;
      case 72: /* cmd ::= select */
#line 454 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy479, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy479);
  sql_select_delete(pParse->db, yymsp[0].minor.yy479);
}
#line 2729 "parse.c"
        break;
      case 73: /* select ::= with selectnowith */
#line 497 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy479;
  if( p ){
    p->pWith = yymsp[-1].minor.yy231;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy231);
  }
  yymsp[-1].minor.yy479 = p; /*A-overwrites-W*/
}
#line 2743 "parse.c"
        break;
      case 74: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 510 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy479;
  Select *pLhs = yymsp[-2].minor.yy479;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy116;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy116!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy479 = pRhs;
}
#line 2769 "parse.c"
        break;
      case 75: /* multiselect_op ::= UNION */
      case 77: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==77);
#line 533 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2775 "parse.c"
        break;
      case 76: /* multiselect_op ::= UNION ALL */
#line 534 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy116 = TK_ALL;}
#line 2780 "parse.c"
        break;
      case 78: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 538 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy320.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy338);
  yymsp[-8].minor.yy479 = sqlSelectNew(pParse,yymsp[-6].minor.yy338,yymsp[-5].minor.yy39,yymsp[-4].minor.yy366,yymsp[-3].minor.yy338,yymsp[-2].minor.yy366,yymsp[-1].minor.yy338,yymsp[-7].minor.yy116,yymsp[0].minor.yy320.pLimit,yymsp[0].minor.yy320.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy479!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy479->zSelName), yymsp[-8].minor.yy479->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy479->zSelName), yymsp[-8].minor.yy479->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2816 "parse.c"
        break;
      case 79: /* values ::= VALUES LP nexprlist RP */
#line 574 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy479 = sqlSelectNew(pParse,yymsp[-1].minor.yy338,0,0,0,0,0,SF_Values,0,0);
}
#line 2823 "parse.c"
        break;
      case 80: /* values ::= values COMMA LP exprlist RP */
#line 577 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy479;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy338,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy479 = pRight;
  }else{
    yymsp[-4].minor.yy479 = pLeft;
  }
}
#line 2839 "parse.c"
        break;
      case 81: /* distinct ::= DISTINCT */
#line 594 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = SF_Distinct;}
#line 2844 "parse.c"
        break;
      case 82: /* distinct ::= ALL */
#line 595 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = SF_All;}
#line 2849 "parse.c"
        break;
      case 84: /* sclp ::= */
      case 110: /* orderby_opt ::= */ yytestcase(yyruleno==110);
      case 121: /* groupby_opt ::= */ yytestcase(yyruleno==121);
      case 207: /* exprlist ::= */ yytestcase(yyruleno==207);
      case 210: /* paren_exprlist ::= */ yytestcase(yyruleno==210);
      case 215: /* eidlist_opt ::= */ yytestcase(yyruleno==215);
#line 608 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy338 = 0;}
#line 2859 "parse.c"
        break;
      case 85: /* selcollist ::= sclp expr as */
#line 609 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy338 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy338, yymsp[-1].minor.yy382.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy338, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy338,&yymsp[-1].minor.yy382);
}
#line 2868 "parse.c"
        break;
      case 86: /* selcollist ::= sclp STAR */
#line 614 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy338 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy338, p);
}
#line 2880 "parse.c"
        break;
      case 87: /* selcollist ::= sclp nm DOT STAR */
#line 622 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy338, pDot);
}
#line 2894 "parse.c"
        break;
      case 88: /* as ::= AS nm */
#line 637 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2899 "parse.c"
        break;
      case 89: /* as ::= */
#line 639 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2904 "parse.c"
        break;
      case 90: /* from ::= */
#line 651 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy39 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy39));}
#line 2909 "parse.c"
        break;
      case 91: /* from ::= FROM seltablist */
#line 652 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy39 = yymsp[0].minor.yy39;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy39);
}
#line 2917 "parse.c"
        break;
      case 92: /* stl_prefix ::= seltablist joinop */
#line 660 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy39 && yymsp[-1].minor.yy39->nSrc>0) ) yymsp[-1].minor.yy39->a[yymsp[-1].minor.yy39->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy116;
}
#line 2924 "parse.c"
        break;
      case 93: /* stl_prefix ::= */
#line 663 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy39 = 0;}
#line 2929 "parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 665 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy39 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy39,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy366,yymsp[0].minor.yy40);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy39, &yymsp[-2].minor.yy0);
}
#line 2937 "parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 670 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy39 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy39,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy366,yymsp[0].minor.yy40);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy39, yymsp[-4].minor.yy338);
}
#line 2945 "parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 675 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy39 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy39,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy479,yymsp[-1].minor.yy366,yymsp[0].minor.yy40);
}
#line 2952 "parse.c"
        break;
      case 97: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy39==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy366==0 && yymsp[0].minor.yy40==0 ){
    yymsp[-6].minor.yy39 = yymsp[-4].minor.yy39;
  }else if( yymsp[-4].minor.yy39->nSrc==1 ){
    yymsp[-6].minor.yy39 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy39,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy366,yymsp[0].minor.yy40);
    if( yymsp[-6].minor.yy39 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy39->a[yymsp[-6].minor.yy39->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy39->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy39);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy39);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy39,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy39 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy39,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy366,yymsp[0].minor.yy40);
  }
}
#line 2977 "parse.c"
        break;
      case 98: /* fullname ::= nm */
#line 703 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /* yylhsminor.yy39-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy39 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy39 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 2989 "parse.c"
  yymsp[0].minor.yy39 = yylhsminor.yy39;
        break;
      case 99: /* joinop ::= COMMA|JOIN */
#line 716 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = JT_INNER; }
#line 2995 "parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW JOIN */
#line 718 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy116 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3000 "parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm JOIN */
#line 720 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy116 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3005 "parse.c"
        break;
      case 102: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 722 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-3].minor.yy116 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3010 "parse.c"
        break;
      case 103: /* on_opt ::= ON expr */
      case 124: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==124);
      case 132: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==132);
      case 205: /* case_else ::= ELSE expr */ yytestcase(yyruleno==205);
#line 726 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy366 = yymsp[0].minor.yy382.pExpr;}
#line 3018 "parse.c"
        break;
      case 104: /* on_opt ::= */
      case 123: /* having_opt ::= */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= */ yytestcase(yyruleno==131);
      case 206: /* case_else ::= */ yytestcase(yyruleno==206);
#line 727 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy366 = 0;}
#line 3026 "parse.c"
        break;
      case 105: /* indexed_opt ::= */
#line 740 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3031 "parse.c"
        break;
      case 106: /* indexed_opt ::= INDEXED BY nm */
#line 741 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3036 "parse.c"
        break;
      case 107: /* indexed_opt ::= NOT INDEXED */
#line 742 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3041 "parse.c"
        break;
      case 108: /* using_opt ::= USING LP idlist RP */
#line 746 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-3].minor.yy40 = yymsp[-1].minor.yy40;}
#line 3046 "parse.c"
        break;
      case 109: /* using_opt ::= */
      case 142: /* idlist_opt ::= */ yytestcase(yyruleno==142);
#line 747 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy40 = 0;}
#line 3052 "parse.c"
        break;
      case 111: /* orderby_opt ::= ORDER BY sortlist */
      case 122: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==122);
#line 761 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy338 = yymsp[0].minor.yy338;}
#line 3058 "parse.c"
        break;
      case 112: /* sortlist ::= sortlist COMMA expr sortorder */
#line 762 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy338,yymsp[-1].minor.yy382.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy338,yymsp[0].minor.yy116);
}
#line 3066 "parse.c"
        break;
      case 113: /* sortlist ::= expr sortorder */
#line 766 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /* yylhsminor.yy338-overwrites-yymsp[-1].minor.yy382. */
  yylhsminor.yy338 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy382.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy338,yymsp[0].minor.yy116);
}
#line 3075 "parse.c"
  yymsp[-1].minor.yy338 = yylhsminor.yy338;
        break;
      case 114: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 780 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy116 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy382.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy338 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy338, yymsp[-1].minor.yy382.pExpr);
}
#line 3090 "parse.c"
        break;
      case 115: /* col_list_with_autoinc ::= expr autoinc */
#line 791 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy116 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy382.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy338-overwrites-yymsp[-1].minor.yy382. */
  yylhsminor.yy338 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy382.pExpr);
}
#line 3105 "parse.c"
  yymsp[-1].minor.yy338 = yylhsminor.yy338;
        break;
      case 116: /* enable ::= ENABLE */
#line 804 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy461 = true;}
#line 3111 "parse.c"
        break;
      case 117: /* enable ::= DISABLE */
#line 805 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy461 = false;}
#line 3116 "parse.c"
        break;
      case 118: /* sortorder ::= ASC */
#line 809 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = SORT_ORDER_ASC;}
#line 3121 "parse.c"
        break;
      case 119: /* sortorder ::= DESC */
#line 810 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = SORT_ORDER_DESC;}
#line 3126 "parse.c"
        break;
      case 120: /* sortorder ::= */
#line 811 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy116 = SORT_ORDER_UNDEF;}
#line 3131 "parse.c"
        break;
      case 125: /* limit_opt ::= */
#line 836 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy320.pLimit = 0; yymsp[1].minor.yy320.pOffset = 0;}
#line 3136 "parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr */
#line 837 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy320.pLimit = yymsp[0].minor.yy382.pExpr; yymsp[-1].minor.yy320.pOffset = 0;}
#line 3141 "parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 839 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-3].minor.yy320.pLimit = yymsp[-2].minor.yy382.pExpr; yymsp[-3].minor.yy320.pOffset = yymsp[0].minor.yy382.pExpr;}
#line 3146 "parse.c"
        break;
      case 128: /* limit_opt ::= LIMIT expr COMMA expr */
#line 841 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-3].minor.yy320.pOffset = yymsp[-2].minor.yy382.pExpr; yymsp[-3].minor.yy320.pLimit = yymsp[0].minor.yy382.pExpr;}
#line 3151 "parse.c"
        break;
      case 129: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 845 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy231, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy39, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy39,yymsp[0].minor.yy366);
}
#line 3163 "parse.c"
        break;
      case 130: /* cmd ::= TRUNCATE TABLE fullname */
#line 856 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy39);
}
#line 3171 "parse.c"
        break;
      case 133: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 870 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy231, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy39, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy338 != NULL && yymsp[-1].minor.yy338->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy338->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy39,yymsp[-1].minor.yy338,yymsp[0].minor.yy366,yymsp[-5].minor.yy116);
}
#line 3188 "parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA nm EQ expr */
#line 887 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy338 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy338, yymsp[0].minor.yy382.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy338, &yymsp[-2].minor.yy0, 1);
}
#line 3196 "parse.c"
        break;
      case 135: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 891 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy338 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy338, yymsp[-3].minor.yy40, yymsp[0].minor.yy382.pExpr);
}
#line 3203 "parse.c"
        break;
      case 136: /* setlist ::= nm EQ expr */
#line 894 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy338 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy382.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy338, &yymsp[-2].minor.yy0, 1);
}
#line 3211 "parse.c"
  yymsp[-2].minor.yy338 = yylhsminor.yy338;
        break;
      case 137: /* setlist ::= LP idlist RP EQ expr */
#line 898 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy338 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy40, yymsp[0].minor.yy382.pExpr);
}
#line 3219 "parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 904 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy231, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy39, yymsp[0].minor.yy479, yymsp[-1].minor.yy40, yymsp[-4].minor.yy116);
}
#line 3230 "parse.c"
        break;
      case 139: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 912 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy231, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy39, 0, yymsp[-2].minor.yy40, yymsp[-5].minor.yy116);
}
#line 3241 "parse.c"
        break;
      case 143: /* idlist_opt ::= LP idlist RP */
#line 930 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy40 = yymsp[-1].minor.yy40;}
#line 3246 "parse.c"
        break;
      case 144: /* idlist ::= idlist COMMA nm */
#line 931 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy40 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy40,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy40 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3257 "parse.c"
        break;
      case 145: /* idlist ::= nm */
#line 938 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /* yylhsminor.yy40-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy40 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy40 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3269 "parse.c"
  yymsp[0].minor.yy40 = yylhsminor.yy40;
        break;
      case 146: /* expr ::= LP expr RP */
#line 1041 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy382,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy382.pExpr = yymsp[-1].minor.yy382.pExpr;}
#line 3275 "parse.c"
        break;
      case 147: /* term ::= NULL */
      case 151: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==151);
      case 152: /* term ::= STRING */ yytestcase(yyruleno==152);
      case 153: /* term ::= FALSE */ yytestcase(yyruleno==153);
      case 154: /* term ::= TRUE */ yytestcase(yyruleno==154);
      case 155: /* term ::= UNKNOWN */ yytestcase(yyruleno==155);
#line 1042 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy382,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3285 "parse.c"
        break;
      case 148: /* expr ::= ID|INDEXED */
      case 149: /* expr ::= JOIN_KW */ yytestcase(yyruleno==149);
#line 1043 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy382,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3291 "parse.c"
        break;
      case 150: /* expr ::= nm DOT nm */
#line 1045 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy382,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy382.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3310 "parse.c"
        break;
      case 156: /* term ::= INTEGER */
#line 1066 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy382.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy382.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy382.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy382.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy382.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy382.pExpr ) yylhsminor.yy382.pExpr->flags |= EP_Leaf;
}
#line 3325 "parse.c"
  yymsp[0].minor.yy382 = yylhsminor.yy382;
        break;
      case 157: /* expr ::= VARIABLE */
#line 1077 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy382, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy382.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy382, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy382.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy382.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy382, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy382.pExpr = NULL;
  }
}
#line 3355 "parse.c"
  yymsp[0].minor.yy382 = yylhsminor.yy382;
        break;
      case 158: /* expr ::= expr COLLATE ID|INDEXED */
#line 1102 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy382.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy382.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy382.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3364 "parse.c"
        break;
      case 159: /* expr ::= CAST LP expr AS typedef RP */
#line 1107 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy382,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy382.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy382.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy382.pExpr->type = yymsp[-1].minor.yy518.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy382.pExpr, yymsp[-3].minor.yy382.pExpr, 0);
}
#line 3378 "parse.c"
        break;
      case 160: /* expr ::= TRIM LP trim_operands RP */
#line 1118 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy382.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy179, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy382, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3386 "parse.c"
  yymsp[-3].minor.yy382 = yylhsminor.yy382;
        break;
      case 161: /* trim_operands ::= trim_from_clause expr */
#line 1126 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy179 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy179, yymsp[0].minor.yy382.pExpr);
}
#line 3394 "parse.c"
  yymsp[-1].minor.yy179 = yylhsminor.yy179;
        break;
      case 162: /* trim_operands ::= expr */
#line 1130 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy179 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy382.pExpr);
}
#line 3402 "parse.c"
  yymsp[0].minor.yy179 = yylhsminor.yy179;
        break;
      case 163: /* trim_from_clause ::= expr FROM */
#line 1142 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy179 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy382.pExpr);
}
#line 3410 "parse.c"
  yymsp[-1].minor.yy179 = yylhsminor.yy179;
        break;
      case 164: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1146 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy157]);
  yylhsminor.yy179 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy443 != NULL)
    yylhsminor.yy179 = sql_expr_list_append(pParse->db, yylhsminor.yy179, yymsp[-1].minor.yy443);
}
#line 3422 "parse.c"
  yymsp[-2].minor.yy179 = yylhsminor.yy179;
        break;
      case 165: /* expr_optional ::= */
#line 1157 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy443 = NULL; }
#line 3428 "parse.c"
        break;
      case 166: /* expr_optional ::= expr */
#line 1158 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yylhsminor.yy443 = yymsp[0].minor.yy382.pExpr; }
#line 3433 "parse.c"
  yymsp[0].minor.yy443 = yylhsminor.yy443;
        break;
      case 167: /* trim_specification ::= LEADING */
#line 1162 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_LEADING; }
#line 3439 "parse.c"
        break;
      case 168: /* trim_specification ::= TRAILING */
#line 1163 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_TRAILING; }
#line 3444 "parse.c"
        break;
      case 169: /* trim_specification ::= BOTH */
#line 1164 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy157 = TRIM_BOTH; }
#line 3449 "parse.c"
        break;
      case 170: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 171: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==171);
#line 1166 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy338 && yymsp[-1].minor.yy338->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy338->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy382.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy338, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy382,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy116==SF_Distinct && yylhsminor.yy382.pExpr ){
    yylhsminor.yy382.pExpr->flags |= EP_Distinct;
  }
}
#line 3468 "parse.c"
  yymsp[-4].minor.yy382 = yylhsminor.yy382;
        break;
      case 172: /* expr ::= ID|INDEXED LP STAR RP */
#line 1201 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy382.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy382,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3477 "parse.c"
  yymsp[-3].minor.yy382 = yylhsminor.yy382;
        break;
      case 173: /* expr ::= LP nexprlist COMMA expr RP */
#line 1236 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy338, yymsp[-1].minor.yy382.pExpr);
  yylhsminor.yy382.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy382.pExpr ){
    yylhsminor.yy382.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy382, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3492 "parse.c"
  yymsp[-4].minor.yy382 = yylhsminor.yy382;
        break;
      case 174: /* expr ::= expr AND expr */
      case 175: /* expr ::= expr OR expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==180);
      case 181: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==181);
#line 1247 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy382,&yymsp[0].minor.yy382);}
#line 3505 "parse.c"
        break;
      case 182: /* likeop ::= LIKE_KW|MATCH */
#line 1260 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3510 "parse.c"
        break;
      case 183: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1261 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3515 "parse.c"
        break;
      case 184: /* expr ::= expr likeop expr */
#line 1262 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy382.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy382.pExpr);
  yymsp[-2].minor.yy382.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy382);
  yymsp[-2].minor.yy382.zEnd = yymsp[0].minor.yy382.zEnd;
  if( yymsp[-2].minor.yy382.pExpr ) yymsp[-2].minor.yy382.pExpr->flags |= EP_InfixFunc;
}
#line 3530 "parse.c"
        break;
      case 185: /* expr ::= expr likeop expr ESCAPE expr */
#line 1273 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy382.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy382.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy382.pExpr);
  yymsp[-4].minor.yy382.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy382);
  yymsp[-4].minor.yy382.zEnd = yymsp[0].minor.yy382.zEnd;
  if( yymsp[-4].minor.yy382.pExpr ) yymsp[-4].minor.yy382.pExpr->flags |= EP_InfixFunc;
}
#line 3546 "parse.c"
        break;
      case 186: /* expr ::= expr IS NULL */
#line 1303 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy382,&yymsp[0].minor.yy0);}
#line 3551 "parse.c"
        break;
      case 187: /* expr ::= expr IS NOT NULL */
#line 1304 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy382,&yymsp[0].minor.yy0);}
#line 3556 "parse.c"
        break;
      case 188: /* expr ::= NOT expr */
      case 189: /* expr ::= BITNOT expr */ yytestcase(yyruleno==189);
#line 1326 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy382,pParse,yymsp[-1].major,&yymsp[0].minor.yy382,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3562 "parse.c"
        break;
      case 190: /* expr ::= MINUS expr */
#line 1330 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy382,pParse,TK_UMINUS,&yymsp[0].minor.yy382,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3567 "parse.c"
        break;
      case 191: /* expr ::= PLUS expr */
#line 1332 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy382,pParse,TK_UPLUS,&yymsp[0].minor.yy382,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3572 "parse.c"
        break;
      case 192: /* between_op ::= BETWEEN */
      case 195: /* in_op ::= IN */ yytestcase(yyruleno==195);
#line 1335 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = 0;}
#line 3578 "parse.c"
        break;
      case 194: /* expr ::= expr between_op expr AND expr */
#line 1337 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy382.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy382.pExpr);
  yymsp[-4].minor.yy382.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy382.pExpr, 0);
  if( yymsp[-4].minor.yy382.pExpr ){
    yymsp[-4].minor.yy382.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy116, &yymsp[-4].minor.yy382);
  yymsp[-4].minor.yy382.zEnd = yymsp[0].minor.yy382.zEnd;
}
#line 3594 "parse.c"
        break;
      case 197: /* expr ::= expr in_op LP exprlist RP */
#line 1352 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy338==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy382.pExpr, false);
    int tk = yymsp[-3].minor.yy116 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy382.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy382.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy382.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy338->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy338->a[0].pExpr;
    yymsp[-1].minor.yy338->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy338);
    yymsp[-4].minor.yy382.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy116 ? TK_NE : TK_EQ, yymsp[-4].minor.yy382.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy382.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy382.pExpr, 0);
    if( yymsp[-4].minor.yy382.pExpr ){
      yymsp[-4].minor.yy382.pExpr->x.pList = yymsp[-1].minor.yy338;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy382.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy338);
    }
    exprNot(pParse, yymsp[-3].minor.yy116, &yymsp[-4].minor.yy382);
  }
  yymsp[-4].minor.yy382.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3644 "parse.c"
        break;
      case 198: /* expr ::= LP select RP */
#line 1398 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy382,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy382.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy382.pExpr, yymsp[-1].minor.yy479);
}
#line 3653 "parse.c"
        break;
      case 199: /* expr ::= expr in_op LP select RP */
#line 1403 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy382.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy382.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy382.pExpr, yymsp[-1].minor.yy479);
  exprNot(pParse, yymsp[-3].minor.yy116, &yymsp[-4].minor.yy382);
  yymsp[-4].minor.yy382.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3663 "parse.c"
        break;
      case 200: /* expr ::= expr in_op nm paren_exprlist */
#line 1409 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy338 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy338);
  yymsp[-3].minor.yy382.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy382.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy382.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy116, &yymsp[-3].minor.yy382);
  yymsp[-3].minor.yy382.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3680 "parse.c"
        break;
      case 201: /* expr ::= EXISTS LP select RP */
#line 1422 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy382,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy382.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy479);
}
#line 3690 "parse.c"
        break;
      case 202: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1430 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy382,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy382.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy443, 0);
  if( yymsp[-4].minor.yy382.pExpr ){
    yymsp[-4].minor.yy382.pExpr->x.pList = yymsp[-1].minor.yy366 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy338,yymsp[-1].minor.yy366) : yymsp[-2].minor.yy338;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy382.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy338);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy366, false);
  }
}
#line 3705 "parse.c"
        break;
      case 203: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1443 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy338, yymsp[-2].minor.yy382.pExpr);
  yymsp[-4].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy338, yymsp[0].minor.yy382.pExpr);
}
#line 3713 "parse.c"
        break;
      case 204: /* case_exprlist ::= WHEN expr THEN expr */
#line 1447 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy338 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy382.pExpr);
  yymsp[-3].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy338, yymsp[0].minor.yy382.pExpr);
}
#line 3721 "parse.c"
        break;
      case 208: /* nexprlist ::= nexprlist COMMA expr */
#line 1464 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy338 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy338,yymsp[0].minor.yy382.pExpr);}
#line 3726 "parse.c"
        break;
      case 209: /* nexprlist ::= expr */
#line 1466 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy338 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy382.pExpr); /*A-overwrites-Y*/}
#line 3731 "parse.c"
        break;
      case 211: /* paren_exprlist ::= LP exprlist RP */
      case 216: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==216);
#line 1473 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy338 = yymsp[-1].minor.yy338;}
#line 3737 "parse.c"
        break;
      case 212: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1479 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy338, yymsp[-8].minor.yy116,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy116);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3752 "parse.c"
        break;
      case 213: /* uniqueflag ::= UNIQUE */
#line 1492 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = SQL_INDEX_TYPE_UNIQUE;}
#line 3757 "parse.c"
        break;
      case 214: /* uniqueflag ::= */
#line 1493 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy116 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3762 "parse.c"
        break;
      case 217: /* eidlist ::= eidlist COMMA nm */
#line 1528 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy338 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy338, &yymsp[0].minor.yy0);
}
#line 3769 "parse.c"
        break;
      case 218: /* eidlist ::= nm */
#line 1531 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[0].minor.yy338 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3776 "parse.c"
        break;
      case 219: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1538 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy39, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy116);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3785 "parse.c"
        break;
      case 220: /* cmd ::= PRAGMA nm */
#line 1546 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3792 "parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm LP nm RP */
#line 1549 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3799 "parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1552 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3806 "parse.c"
        break;
      case 223: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1557 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy255, &all);
}
#line 3817 "parse.c"
        break;
      case 224: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1567 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy39, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy116, yymsp[-4].minor.yy434.a, yymsp[-4].minor.yy434.b, yymsp[0].minor.yy366,
                          yymsp[-7].minor.yy116);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3827 "parse.c"
        break;
      case 225: /* trigger_time ::= BEFORE */
#line 1575 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = TK_BEFORE; }
#line 3832 "parse.c"
        break;
      case 226: /* trigger_time ::= AFTER */
#line 1576 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = TK_AFTER;  }
#line 3837 "parse.c"
        break;
      case 227: /* trigger_time ::= INSTEAD OF */
#line 1577 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = TK_INSTEAD;}
#line 3842 "parse.c"
        break;
      case 228: /* trigger_time ::= */
#line 1578 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy116 = TK_BEFORE; }
#line 3847 "parse.c"
        break;
      case 229: /* trigger_event ::= DELETE|INSERT */
      case 230: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==230);
#line 1582 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy434.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy434.b = 0;}
#line 3853 "parse.c"
        break;
      case 231: /* trigger_event ::= UPDATE OF idlist */
#line 1584 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[-2].minor.yy434.a = TK_UPDATE; yymsp[-2].minor.yy434.b = yymsp[0].minor.yy40;}
#line 3858 "parse.c"
        break;
      case 232: /* foreach_clause ::= */
#line 1586 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3868 "parse.c"
        break;
      case 233: /* when_clause ::= */
#line 1596 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[1].minor.yy366 = 0; }
#line 3873 "parse.c"
        break;
      case 234: /* when_clause ::= WHEN expr */
#line 1597 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy366 = yymsp[0].minor.yy382.pExpr; }
#line 3878 "parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1601 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy255!=0 );
  yymsp[-2].minor.yy255->pLast->pNext = yymsp[-1].minor.yy255;
  yymsp[-2].minor.yy255->pLast = yymsp[-1].minor.yy255;
}
#line 3887 "parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1606 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy255!=0 );
  yymsp[-1].minor.yy255->pLast = yymsp[-1].minor.yy255;
}
#line 3895 "parse.c"
        break;
      case 237: /* trnm ::= nm DOT nm */
#line 1617 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3906 "parse.c"
        break;
      case 238: /* tridxby ::= INDEXED BY nm */
#line 1630 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3916 "parse.c"
        break;
      case 239: /* tridxby ::= NOT INDEXED */
#line 1636 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3926 "parse.c"
        break;
      case 240: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1649 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy255 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy338, yymsp[0].minor.yy366, yymsp[-5].minor.yy116);
     if (yymsp[-6].minor.yy255 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3937 "parse.c"
        break;
      case 241: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1658 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /*yylhsminor.yy255-overwrites-yymsp[-4].minor.yy116. */
  yylhsminor.yy255 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy40, yymsp[0].minor.yy479, yymsp[-4].minor.yy116);
  if (yylhsminor.yy255 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3949 "parse.c"
  yymsp[-4].minor.yy255 = yylhsminor.yy255;
        break;
      case 242: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1668 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy255 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy366);
  if (yymsp[-4].minor.yy255 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3961 "parse.c"
        break;
      case 243: /* trigger_cmd ::= select */
#line 1677 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  /* yylhsminor.yy255-overwrites-yymsp[0].minor.yy479. */
  yylhsminor.yy255 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy479);
  if (yylhsminor.yy255 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3973 "parse.c"
  yymsp[0].minor.yy255 = yylhsminor.yy255;
        break;
      case 244: /* expr ::= RAISE LP IGNORE RP */
#line 1687 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy382,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy382.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy382.pExpr ){
    yymsp[-3].minor.yy382.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 3985 "parse.c"
        break;
      case 245: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1694 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy382,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy382.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy382.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy382.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy116;
}
#line 3998 "parse.c"
        break;
      case 246: /* raisetype ::= ROLLBACK */
#line 1705 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4003 "parse.c"
        break;
      case 247: /* raisetype ::= ABORT */
#line 1706 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = ON_CONFLICT_ACTION_ABORT;}
#line 4008 "parse.c"
        break;
      case 248: /* raisetype ::= FAIL */
#line 1707 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[0].minor.yy116 = ON_CONFLICT_ACTION_FAIL;}
#line 4013 "parse.c"
        break;
      case 249: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1711 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy39, &t, yymsp[-1].minor.yy116);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4023 "parse.c"
        break;
      case 250: /* alter_table_start ::= ALTER TABLE fullname */
#line 1728 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-2].minor.yy396 = yymsp[0].minor.yy39; }
#line 4028 "parse.c"
        break;
      case 251: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1731 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yylhsminor.yy158.table_name = yymsp[-3].minor.yy396;
  yylhsminor.yy158.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4037 "parse.c"
  yymsp[-3].minor.yy158 = yylhsminor.yy158;
        break;
      case 252: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1738 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy158.table_name, &yymsp[-11].minor.yy158.name, yymsp[-7].minor.yy338, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy338,
                     yymsp[-2].minor.yy116, yymsp[-1].minor.yy116, yymsp[0].minor.yy116);
  sql_create_foreign_key(pParse);
}
#line 4047 "parse.c"
        break;
      case 253: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1744 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy158.table_name, &yymsp[-4].minor.yy158.name, &yymsp[-1].minor.yy382);
    sql_create_check_contraint(pParse);
}
#line 4055 "parse.c"
        break;
      case 254: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1749 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy158.table_name, &yymsp[-4].minor.yy158.name, yymsp[-1].minor.yy338, yymsp[-3].minor.yy116,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4064 "parse.c"
        break;
      case 255: /* unique_spec ::= UNIQUE */
#line 1756 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy116 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4069 "parse.c"
        break;
      case 256: /* unique_spec ::= PRIMARY KEY */
#line 1757 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy116 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4074 "parse.c"
        break;
      case 257: /* cmd ::= alter_table_start RENAME TO nm */
#line 1759 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy396, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4083 "parse.c"
        break;
      case 258: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1765 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  drop_fk_def_init(&pParse->drop_fk_def, yymsp[-3].minor.yy39, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_foreign_key(pParse);
}
#line 4092 "parse.c"
        break;
      case 259: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1771 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy396,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy461);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4101 "parse.c"
        break;
      case 260: /* with ::= */
#line 1783 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{yymsp[1].minor.yy231 = 0;}
#line 4106 "parse.c"
        break;
      case 261: /* with ::= WITH wqlist */
#line 1784 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-1].minor.yy231 = yymsp[0].minor.yy231; }
#line 4111 "parse.c"
        break;
      case 262: /* with ::= WITH RECURSIVE wqlist */
#line 1785 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[-2].minor.yy231 = yymsp[0].minor.yy231; }
#line 4116 "parse.c"
        break;
      case 263: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1787 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy231 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy338, yymsp[-1].minor.yy479); /*A-overwrites-X*/
}
#line 4123 "parse.c"
        break;
      case 264: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1790 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy231 = sqlWithAdd(pParse, yymsp[-7].minor.yy231, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy338, yymsp[-1].minor.yy479);
}
#line 4130 "parse.c"
        break;
      case 265: /* typedef ::= TEXT */
      case 266: /* typedef ::= STRING_KW */ yytestcase(yyruleno==266);
#line 1796 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_STRING; }
#line 4136 "parse.c"
        break;
      case 267: /* typedef ::= SCALAR */
#line 1798 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_SCALAR; }
#line 4141 "parse.c"
        break;
      case 268: /* typedef ::= BOOL */
      case 269: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==269);
#line 1800 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_BOOLEAN; }
#line 4147 "parse.c"
        break;
      case 270: /* typedef ::= VARBINARY */
#line 1802 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_VARBINARY; }
#line 4152 "parse.c"
        break;
      case 271: /* char_len ::= LP INTEGER RP */
#line 1814 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy116;
  (void) yymsp[-1].minor.yy0;
}
#line 4160 "parse.c"
        break;
      case 272: /* typedef ::= VARCHAR char_len */
#line 1820 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy518.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy116;
}
#line 4168 "parse.c"
        break;
      case 273: /* number_typedef ::= NUMBER */
#line 1827 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_NUMBER; }
#line 4173 "parse.c"
        break;
      case 274: /* number_typedef ::= DOUBLE */
#line 1828 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_DOUBLE; }
#line 4178 "parse.c"
        break;
      case 275: /* number_typedef ::= INT|INTEGER_KW */
#line 1829 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_INTEGER; }
#line 4183 "parse.c"
        break;
      case 276: /* number_typedef ::= UNSIGNED */
#line 1830 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"
{ yymsp[0].minor.yy518.type = FIELD_TYPE_UNSIGNED; }
#line 4188 "parse.c"
        break;
      default:
      /* (277) input ::= ecmd */ yytestcase(yyruleno==277);
      /* (278) explain ::= */ yytestcase(yyruleno==278);
      /* (279) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=279);
      /* (280) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==280);
      /* (281) savepoint_opt ::= */ yytestcase(yyruleno==281);
      /* (282) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==282);
      /* (283) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==283);
      /* (284) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==284);
      /* (285) with_opts ::= */ yytestcase(yyruleno==285);
      /* (286) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==286);
      /* (287) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=287);
      /* (288) carglist ::= carglist ccons */ yytestcase(yyruleno==288);
      /* (289) carglist ::= */ yytestcase(yyruleno==289);
      /* (290) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=290);
      /* (291) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=291);
      /* (292) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=292);
      /* (293) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=293);
      /* (294) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=294);
      /* (295) oneselect ::= values */ yytestcase(yyruleno==295);
      /* (296) sclp ::= selcollist COMMA */ yytestcase(yyruleno==296);
      /* (297) as ::= ID|STRING */ yytestcase(yyruleno==297);
      /* (298) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==298);
      /* (299) join_nm ::= JOIN_KW */ yytestcase(yyruleno==299);
      /* (300) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=300);
      /* (301) type_func ::= CHAR */ yytestcase(yyruleno==301);
      /* (302) exprlist ::= nexprlist */ yytestcase(yyruleno==302);
      /* (303) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==303);
      /* (304) trnm ::= nm */ yytestcase(yyruleno==304);
      /* (305) tridxby ::= */ yytestcase(yyruleno==305);
      /* (306) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=306);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.3.2.17/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4289 "parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
